'''OpenGL extension ARB.occlusion_query2

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.occlusion_query2 to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension trivially adds a boolean occlusion query
	to ARB_occlusion_query.
	
	While the counter-based occlusion query provided by
	ARB_occlusion_query is flexible, there is still value
	to a simple boolean, which is often sufficient for applications.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/occlusion_query2.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.occlusion_query2 import *
from OpenGL.raw.GL.ARB.occlusion_query2 import _EXTENSION_NAME

def glInitOcclusionQuery2ARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


"""Base class for GLU callback-caching structures"""
import ctypes
import weakref
from OpenGL._bytes import long, integer_types

class GLUStruct( object ):
    """Mix-in class for GLU Structures that want to retain references to callbacks
    
    Also provides original-object-return for the "datapointer" style paremters
    
    Each sub-class must override:
        CALLBACK_TYPES -- maps a "which" constant to a function type 
        CALLBACK_FUNCTION_REGISTRARS -- maps a "which" constant to the 
            registration function for functions of that type
        WRAPPER_METHODS -- maps a "which" consant to a method of the structure 
            that produces a callable around the function which takes care of 
            input/output arguments, data conversions, error handling and the 
            like.
    Creates a dictionary member dataPointers if original-object-return is used
    Creates a dictionary member callbacks if callback registration is used
    """
    def getAsParam( self ):
        """Gets as a ctypes pointer to the underlying structure"""
        return ctypes.pointer( self )
    _as_parameter_ = property( getAsParam )
    CALLBACK_TYPES = None
    CALLBACK_FUNCTION_REGISTRARS = None
    WRAPPER_METHODS = None
    def noteObject( self, object ):
        """Note object for later retrieval as a Python object pointer
        
        This is the registration point for "original object return", returns 
        a void pointer to the Python object, though this is, effectively, an 
        opaque value.
        """
        identity = id(object)
        try:
            self.dataPointers[ identity ] = object
        except AttributeError as err:
            self.dataPointers = { identity: object }
        return identity
    def originalObject( self, voidPointer ):
        """Given a void-pointer, try to find our original Python object"""
        if isinstance( voidPointer, integer_types):
            identity = voidPointer
        elif voidPointer is None:
            return None
        else:
            try:
                identity = voidPointer.value 
            except AttributeError as err:
                identity = voidPointer[0]
        try:
            return self.dataPointers[ identity ]
        except (KeyError,AttributeError) as err:
            return voidPointer
    def addCallback( self, which, function ):
        """Register a callback for this structure object"""
        callbackType = self.CALLBACK_TYPES.get( which )
        if not callbackType:
            raise ValueError(
                """Don't have a registered callback type for %r"""%(
                    which,
                )
            )
        wrapperMethod = self.WRAPPER_METHODS.get( which )
        if wrapperMethod is not None:
            function = getattr(self,wrapperMethod)( function )
        cCallback = callbackType( function )
        # XXX this is ugly, query to ctypes list on how to fix it...
        try:
            self.CALLBACK_FUNCTION_REGISTRARS[which]( self, which, cCallback )
        except ctypes.ArgumentError as err:
            err.args += (which,cCallback)
            raise
        #gluTessCallbackBase( self, which, cCallback)
        # XXX catch errors!
        if getattr( self, 'callbacks', None ) is None:
            self.callbacks = {}
        self.callbacks[ which ] = cCallback
        return cCallback
    def ptrAsArray( self, ptr, length, type ):
        """Copy length values from ptr into new array of given type"""
        result = type.zeros( (length,) )
        for i in range(length):
            result[i] = ptr[i]
        return result



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES1 import _types as _cs
# End users want this...
from OpenGL.raw.GLES1._types import *
from OpenGL.raw.GLES1 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES1_EXT_robustness'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES1,'GLES1_EXT_robustness',error_checker=_errors._error_checker)
GL_CONTEXT_ROBUST_ACCESS_EXT=_C('GL_CONTEXT_ROBUST_ACCESS_EXT',0x90F3)
GL_GUILTY_CONTEXT_RESET_EXT=_C('GL_GUILTY_CONTEXT_RESET_EXT',0x8253)
GL_INNOCENT_CONTEXT_RESET_EXT=_C('GL_INNOCENT_CONTEXT_RESET_EXT',0x8254)
GL_LOSE_CONTEXT_ON_RESET_EXT=_C('GL_LOSE_CONTEXT_ON_RESET_EXT',0x8252)
GL_NO_ERROR=_C('GL_NO_ERROR',0)
GL_NO_RESET_NOTIFICATION_EXT=_C('GL_NO_RESET_NOTIFICATION_EXT',0x8261)
GL_RESET_NOTIFICATION_STRATEGY_EXT=_C('GL_RESET_NOTIFICATION_STRATEGY_EXT',0x8256)
GL_UNKNOWN_CONTEXT_RESET_EXT=_C('GL_UNKNOWN_CONTEXT_RESET_EXT',0x8255)
@_f
@_p.types(_cs.GLenum,)
def glGetGraphicsResetStatusEXT():pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLfloatArray)
def glGetnUniformfvEXT(program,location,bufSize,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLintArray)
def glGetnUniformivEXT(program,location,bufSize,params):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLenum,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glReadnPixelsEXT(x,y,width,height,format,type,bufSize,data):pass



'''OpenGL extension NV.point_sprite

This module customises the behaviour of the 
OpenGL.raw.GL.NV.point_sprite to provide a more 
Python-friendly API

Overview (from the spec)
	
	Applications such as particle systems usually must use OpenGL quads
	rather than points to render their geometry, since they would like to
	use a custom-drawn texture for each particle, rather than the
	traditional OpenGL round antialiased points, and each fragment in
	a point has the same texture coordinates as every other fragment.
	
	Unfortunately, specifying the geometry for these quads can be quite
	expensive, since it quadruples the amount of geometry required, and
	it may also require the application to do extra processing to compute
	the location of each vertex.
	
	The goal of this extension is to allow such apps to use points rather
	than quads.  When GL_POINT_SPRITE_NV is enabled, the state of point
	antialiasing is ignored.  For each texture unit, the app can then
	specify whether to replace the existing texture coordinates with
	point sprite texture coordinates, which are interpolated across the
	point.  Finally, the app can set a global parameter for the way to
	generate the R coordinate for point sprites; the R coordinate can
	either be zero, the input S coordinate, or the input R coordinate.
	This allows applications to use a 3D texture to represent a point
	sprite that goes through an animation, with filtering between frames,
	for example.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/point_sprite.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.point_sprite import *
from OpenGL.raw.GL.NV.point_sprite import _EXTENSION_NAME

def glInitPointSpriteNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glPointParameterivNV.params size not checked against 'pname'
glPointParameterivNV=wrapper.wrapper(glPointParameterivNV).setInputArraySize(
    'params', None
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.WGL import _types as _cs
# End users want this...
from OpenGL.raw.WGL._types import *
from OpenGL.raw.WGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'WGL_NV_video_capture'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.WGL,'WGL_NV_video_capture',error_checker=_errors._error_checker)
WGL_NUM_VIDEO_CAPTURE_SLOTS_NV=_C('WGL_NUM_VIDEO_CAPTURE_SLOTS_NV',0x20CF)
WGL_UNIQUE_ID_NV=_C('WGL_UNIQUE_ID_NV',0x20CE)
@_f
@_p.types(_cs.BOOL,_cs.UINT,_cs.HVIDEOINPUTDEVICENV)
def wglBindVideoCaptureDeviceNV(uVideoSlot,hDevice):pass
@_f
@_p.types(_cs.UINT,_cs.HDC,ctypes.POINTER(_cs.HVIDEOINPUTDEVICENV))
def wglEnumerateVideoCaptureDevicesNV(hDc,phDeviceList):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.HVIDEOINPUTDEVICENV)
def wglLockVideoCaptureDeviceNV(hDc,hDevice):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.HVIDEOINPUTDEVICENV,_cs.c_int,ctypes.POINTER(_cs.c_int))
def wglQueryVideoCaptureDeviceNV(hDc,hDevice,iAttribute,piValue):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.HVIDEOINPUTDEVICENV)
def wglReleaseVideoCaptureDeviceNV(hDc,hDevice):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLX import _types as _cs
# End users want this...
from OpenGL.raw.GLX._types import *
from OpenGL.raw.GLX import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLX_ARB_create_context'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLX,'GLX_ARB_create_context',error_checker=_errors._error_checker)
GLX_CONTEXT_DEBUG_BIT_ARB=_C('GLX_CONTEXT_DEBUG_BIT_ARB',0x00000001)
GLX_CONTEXT_FLAGS_ARB=_C('GLX_CONTEXT_FLAGS_ARB',0x2094)
GLX_CONTEXT_FORWARD_COMPATIBLE_BIT_ARB=_C('GLX_CONTEXT_FORWARD_COMPATIBLE_BIT_ARB',0x00000002)
GLX_CONTEXT_MAJOR_VERSION_ARB=_C('GLX_CONTEXT_MAJOR_VERSION_ARB',0x2091)
GLX_CONTEXT_MINOR_VERSION_ARB=_C('GLX_CONTEXT_MINOR_VERSION_ARB',0x2092)
@_f
@_p.types(_cs.GLXContext,ctypes.POINTER(_cs.Display),_cs.GLXFBConfig,_cs.GLXContext,_cs.Bool,ctypes.POINTER(_cs.c_int))
def glXCreateContextAttribsARB(dpy,config,share_context,direct,attrib_list):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_texture_float'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_texture_float',error_checker=_errors._error_checker)
GL_ALPHA16F_ARB=_C('GL_ALPHA16F_ARB',0x881C)
GL_ALPHA32F_ARB=_C('GL_ALPHA32F_ARB',0x8816)
GL_INTENSITY16F_ARB=_C('GL_INTENSITY16F_ARB',0x881D)
GL_INTENSITY32F_ARB=_C('GL_INTENSITY32F_ARB',0x8817)
GL_LUMINANCE16F_ARB=_C('GL_LUMINANCE16F_ARB',0x881E)
GL_LUMINANCE32F_ARB=_C('GL_LUMINANCE32F_ARB',0x8818)
GL_LUMINANCE_ALPHA16F_ARB=_C('GL_LUMINANCE_ALPHA16F_ARB',0x881F)
GL_LUMINANCE_ALPHA32F_ARB=_C('GL_LUMINANCE_ALPHA32F_ARB',0x8819)
GL_RGB16F_ARB=_C('GL_RGB16F_ARB',0x881B)
GL_RGB32F_ARB=_C('GL_RGB32F_ARB',0x8815)
GL_RGBA16F_ARB=_C('GL_RGBA16F_ARB',0x881A)
GL_RGBA32F_ARB=_C('GL_RGBA32F_ARB',0x8814)
GL_TEXTURE_ALPHA_TYPE_ARB=_C('GL_TEXTURE_ALPHA_TYPE_ARB',0x8C13)
GL_TEXTURE_BLUE_TYPE_ARB=_C('GL_TEXTURE_BLUE_TYPE_ARB',0x8C12)
GL_TEXTURE_DEPTH_TYPE_ARB=_C('GL_TEXTURE_DEPTH_TYPE_ARB',0x8C16)
GL_TEXTURE_GREEN_TYPE_ARB=_C('GL_TEXTURE_GREEN_TYPE_ARB',0x8C11)
GL_TEXTURE_INTENSITY_TYPE_ARB=_C('GL_TEXTURE_INTENSITY_TYPE_ARB',0x8C15)
GL_TEXTURE_LUMINANCE_TYPE_ARB=_C('GL_TEXTURE_LUMINANCE_TYPE_ARB',0x8C14)
GL_TEXTURE_RED_TYPE_ARB=_C('GL_TEXTURE_RED_TYPE_ARB',0x8C10)
GL_UNSIGNED_NORMALIZED_ARB=_C('GL_UNSIGNED_NORMALIZED_ARB',0x8C17)




"""Fix missing-API problems in logging module (circa Python 2.3)

Adds constants to the log objects.
Adds getException(err) to log objects to retrieve 
formatted exception or err if traceback not available.
"""
import traceback, logging
from OpenGL._configflags import ERROR_LOGGING, FULL_LOGGING
getLog = logging.getLogger

def getException(error):
    """Get formatted traceback from exception"""
    try:
        return traceback.format_exc( limit=10 )
    except Exception as err:
        return str( error )

logging.Logger.getException = staticmethod( getException )
logging.Logger.err = logging.Logger.error
logging.Logger.DEBUG = logging.DEBUG 
logging.Logger.WARN = logging.WARN 
logging.Logger.INFO = logging.INFO 
logging.Logger.ERR = logging.Logger.ERROR = logging.ERROR

if FULL_LOGGING:
    getLog( 'OpenGL.calltrace' ).setLevel( logging.INFO )

class _LoggedFunction( object ):
    """Proxy that overrides __call__ to log arguments"""
    def __init__( self, base, log ):
        self.__dict__[''] = base 
        self.__dict__['log'] = log
    def __setattr__( self, key, value ):
        if key != '':
            setattr( self.__dict__[''], key, value )
        else:
            self.__dict__[''] = value 
    def __getattr__( self, key ):
        if key == '':
            return self.__dict__['']
        else:
            return getattr( self.__dict__[''], key )
class _FullLoggedFunction( _LoggedFunction ):
    """Fully-logged function wrapper (logs all call params to OpenGL.calltrace)"""
    _callTrace = getLog( 'OpenGL.calltrace' )
    def __call__( self, *args, **named ):
        argRepr = []
        function = getattr( self, '' )
        for arg in args:
            argRepr.append( repr(arg) )
        for key,value in named.items():
            argRepr.append( '%s = %s'%( key,repr(value)) )
        argRepr = ",".join( argRepr )
        self._callTrace.info( '%s( %s )', function.__name__, argRepr )
        try:
            return function( *args, **named )
        except Exception as err:
            self.log.warning(
                """Failure on %s: %s""", function.__name__, self.log.getException( err )
            )
            raise
class _ErrorLoggedFunction ( _LoggedFunction ):
    """On-error-logged function wrapper"""
    def __call__( self, *args, **named ):
        function = getattr( self, '' )
        try:
            return function( *args, **named )
        except Exception as err:
            self.log.warning(
                """Failure on %s: %s""", function.__name__, self.log.getException( err )
            )
            raise
    

def logOnFail( function, log ):
    """Produce possible log-wrapped version of function

    function -- callable object to be wrapped
    log -- the log to which to log information
    
    Uses ERROR_LOGGING and FULL_LOGGING
    to determine whether/how to wrap the function.
    """
    if ERROR_LOGGING or FULL_LOGGING:
        if FULL_LOGGING:
            loggedFunction = _FullLoggedFunction( function, log )
        else:
            loggedFunction = _ErrorLoggedFunction( function, log )
        return loggedFunction
    else:
        return function



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_NV_texture_border_clamp'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_NV_texture_border_clamp',error_checker=_errors._error_checker)
GL_CLAMP_TO_BORDER_NV=_C('GL_CLAMP_TO_BORDER_NV',0x812D)
GL_TEXTURE_BORDER_COLOR_NV=_C('GL_TEXTURE_BORDER_COLOR_NV',0x1004)




'''OpenGL extension SGIX.shadow_ambient

This module customises the behaviour of the 
OpenGL.raw.GL.SGIX.shadow_ambient to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows a value other than 0.0 to be returned by the
	SGIX_shadow operation in the case when the shadow test passes.
	With this extension any floating point value in the range [0.0,
	1.0] can be returned as the texture value when an object is in
	shadow.  This allows the (untextured) ambient lighting and direct
	shadowed lighting from a single light source to be computed in a
	single pass.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/shadow_ambient.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIX.shadow_ambient import *
from OpenGL.raw.GL.SGIX.shadow_ambient import _EXTENSION_NAME

def glInitShadowAmbientSGIX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLX import _types as _cs
# End users want this...
from OpenGL.raw.GLX._types import *
from OpenGL.raw.GLX import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLX_AMD_gpu_association'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLX,'GLX_AMD_gpu_association',error_checker=_errors._error_checker)
GLX_GPU_CLOCK_AMD=_C('GLX_GPU_CLOCK_AMD',0x21A4)
GLX_GPU_FASTEST_TARGET_GPUS_AMD=_C('GLX_GPU_FASTEST_TARGET_GPUS_AMD',0x21A2)
GLX_GPU_NUM_PIPES_AMD=_C('GLX_GPU_NUM_PIPES_AMD',0x21A5)
GLX_GPU_NUM_RB_AMD=_C('GLX_GPU_NUM_RB_AMD',0x21A7)
GLX_GPU_NUM_SIMD_AMD=_C('GLX_GPU_NUM_SIMD_AMD',0x21A6)
GLX_GPU_NUM_SPI_AMD=_C('GLX_GPU_NUM_SPI_AMD',0x21A8)
GLX_GPU_OPENGL_VERSION_STRING_AMD=_C('GLX_GPU_OPENGL_VERSION_STRING_AMD',0x1F02)
GLX_GPU_RAM_AMD=_C('GLX_GPU_RAM_AMD',0x21A3)
GLX_GPU_RENDERER_STRING_AMD=_C('GLX_GPU_RENDERER_STRING_AMD',0x1F01)
GLX_GPU_VENDOR_AMD=_C('GLX_GPU_VENDOR_AMD',0x1F00)
@_f
@_p.types(None,_cs.GLXContext,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLbitfield,_cs.GLenum)
def glXBlitContextFramebufferAMD(dstCtx,srcX0,srcY0,srcX1,srcY1,dstX0,dstY0,dstX1,dstY1,mask,filter):pass
@_f
@_p.types(_cs.GLXContext,_cs.c_uint,_cs.GLXContext)
def glXCreateAssociatedContextAMD(id,share_list):pass
@_f
@_p.types(_cs.GLXContext,_cs.c_uint,_cs.GLXContext,ctypes.POINTER(_cs.c_int))
def glXCreateAssociatedContextAttribsAMD(id,share_context,attribList):pass
@_f
@_p.types(_cs.Bool,_cs.GLXContext)
def glXDeleteAssociatedContextAMD(ctx):pass
@_f
@_p.types(_cs.c_uint,_cs.GLXContext)
def glXGetContextGPUIDAMD(ctx):pass
@_f
@_p.types(_cs.GLXContext,)
def glXGetCurrentAssociatedContextAMD():pass
@_f
@_p.types(_cs.c_uint,_cs.c_uint,ctypes.POINTER(_cs.c_uint))
def glXGetGPUIDsAMD(maxCount,ids):pass
@_f
@_p.types(_cs.c_int,_cs.c_uint,_cs.c_int,_cs.GLenum,_cs.c_uint,ctypes.c_void_p)
def glXGetGPUInfoAMD(id,property,dataType,size,data):pass
@_f
@_p.types(_cs.Bool,_cs.GLXContext)
def glXMakeAssociatedContextCurrentAMD(ctx):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_ANGLE_d3d_share_handle_client_buffer'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_ANGLE_d3d_share_handle_client_buffer',error_checker=_errors._error_checker)
EGL_D3D_TEXTURE_2D_SHARE_HANDLE_ANGLE=_C('EGL_D3D_TEXTURE_2D_SHARE_HANDLE_ANGLE',0x3200)




'''OpenGL extension SGIX.texture_coordinate_clamp

This module customises the behaviour of the 
OpenGL.raw.GL.SGIX.texture_coordinate_clamp to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a mechanism to specify the maximum texture coordinate
	clamping values. Standard OpenGL always clamps the upper bound to 1.0 when
	the wrap mode is set to CLAMP. This mechanism can be used to  guarantee 
	that non-existent texel data will not be accessed when the texture image has 
	dimensions that are not a power of 2.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/texture_coordinate_clamp.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIX.texture_coordinate_clamp import *
from OpenGL.raw.GL.SGIX.texture_coordinate_clamp import _EXTENSION_NAME

def glInitTextureCoordinateClampSGIX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.shader_integer_mix

This module customises the behaviour of the 
OpenGL.raw.GLES2.EXT.shader_integer_mix to provide a more 
Python-friendly API

Overview (from the spec)
	
	GLSL 1.30 (and GLSL ES 3.00) expanded the mix() built-in function to
	operate on a boolean third argument that does not interpolate but
	selects. This extension extends mix() to select between int, uint,
	and bool components.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/shader_integer_mix.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.EXT.shader_integer_mix import *
from OpenGL.raw.GLES2.EXT.shader_integer_mix import _EXTENSION_NAME

def glInitShaderIntegerMixEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_SUN_triangle_list'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_SUN_triangle_list',error_checker=_errors._error_checker)
GL_R1UI_C3F_V3F_SUN=_C('GL_R1UI_C3F_V3F_SUN',0x85C6)
GL_R1UI_C4F_N3F_V3F_SUN=_C('GL_R1UI_C4F_N3F_V3F_SUN',0x85C8)
GL_R1UI_C4UB_V3F_SUN=_C('GL_R1UI_C4UB_V3F_SUN',0x85C5)
GL_R1UI_N3F_V3F_SUN=_C('GL_R1UI_N3F_V3F_SUN',0x85C7)
GL_R1UI_T2F_C4F_N3F_V3F_SUN=_C('GL_R1UI_T2F_C4F_N3F_V3F_SUN',0x85CB)
GL_R1UI_T2F_N3F_V3F_SUN=_C('GL_R1UI_T2F_N3F_V3F_SUN',0x85CA)
GL_R1UI_T2F_V3F_SUN=_C('GL_R1UI_T2F_V3F_SUN',0x85C9)
GL_R1UI_V3F_SUN=_C('GL_R1UI_V3F_SUN',0x85C4)
GL_REPLACEMENT_CODE_ARRAY_POINTER_SUN=_C('GL_REPLACEMENT_CODE_ARRAY_POINTER_SUN',0x85C3)
GL_REPLACEMENT_CODE_ARRAY_STRIDE_SUN=_C('GL_REPLACEMENT_CODE_ARRAY_STRIDE_SUN',0x85C2)
GL_REPLACEMENT_CODE_ARRAY_SUN=_C('GL_REPLACEMENT_CODE_ARRAY_SUN',0x85C0)
GL_REPLACEMENT_CODE_ARRAY_TYPE_SUN=_C('GL_REPLACEMENT_CODE_ARRAY_TYPE_SUN',0x85C1)
GL_REPLACEMENT_CODE_SUN=_C('GL_REPLACEMENT_CODE_SUN',0x81D8)
GL_REPLACE_MIDDLE_SUN=_C('GL_REPLACE_MIDDLE_SUN',0x0002)
GL_REPLACE_OLDEST_SUN=_C('GL_REPLACE_OLDEST_SUN',0x0003)
GL_RESTART_SUN=_C('GL_RESTART_SUN',0x0001)
GL_TRIANGLE_LIST_SUN=_C('GL_TRIANGLE_LIST_SUN',0x81D7)
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,arrays.GLvoidpArray)
def glReplacementCodePointerSUN(type,stride,pointer):pass
@_f
@_p.types(None,_cs.GLubyte)
def glReplacementCodeubSUN(code):pass
@_f
@_p.types(None,arrays.GLubyteArray)
def glReplacementCodeubvSUN(code):pass
@_f
@_p.types(None,_cs.GLuint)
def glReplacementCodeuiSUN(code):pass
@_f
@_p.types(None,arrays.GLuintArray)
def glReplacementCodeuivSUN(code):pass
@_f
@_p.types(None,_cs.GLushort)
def glReplacementCodeusSUN(code):pass
@_f
@_p.types(None,arrays.GLushortArray)
def glReplacementCodeusvSUN(code):pass



'''OpenGL extension ARB.internalformat_query

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.internalformat_query to provide a more 
Python-friendly API

Overview (from the spec)
	
	OpenGL 4.1 has a number of queries to indicate the maximum number of
	samples available for different formats. These give a coarse-grained
	query mechanism e.g. an implementation can expose different sample
	counts for integer and floating-point formats, but not for different
	floating-point formats. There is also no convenient way for the user
	to determine the granularity of sample counts available, only the
	maximum.
	
	This extension adds a query mechanism that allows the user to
	determine which sample counts are available for a specific internal
	format.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/internalformat_query.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.internalformat_query import *
from OpenGL.raw.GL.ARB.internalformat_query import _EXTENSION_NAME

def glInitInternalformatQueryARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glGetInternalformativ=wrapper.wrapper(glGetInternalformativ).setOutput(
    'params',size=lambda x:(x,),pnameArg='bufSize',orPassIn=True
)
### END AUTOGENERATED SECTION


'''OpenGL extension ARB.texture_rgb10_a2ui

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.texture_rgb10_a2ui to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds support for the following data format:
	
	A new texturing format for unsigned 10.10.10.2 integer textures. 
	
	OpenGL has supported RGB10 and RGB10_A2 formats for a very long time.  
	This extension provides a variant of RGB10_A2 which supports unsigned 
	integer data (in contrast to the above "unsigned normalized integer" 
	formats).

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/texture_rgb10_a2ui.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.texture_rgb10_a2ui import *
from OpenGL.raw.GL.ARB.texture_rgb10_a2ui import _EXTENSION_NAME

def glInitTextureRgb10A2UiARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_INGR_color_clamp'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_INGR_color_clamp',error_checker=_errors._error_checker)
GL_ALPHA_MAX_CLAMP_INGR=_C('GL_ALPHA_MAX_CLAMP_INGR',0x8567)
GL_ALPHA_MIN_CLAMP_INGR=_C('GL_ALPHA_MIN_CLAMP_INGR',0x8563)
GL_BLUE_MAX_CLAMP_INGR=_C('GL_BLUE_MAX_CLAMP_INGR',0x8566)
GL_BLUE_MIN_CLAMP_INGR=_C('GL_BLUE_MIN_CLAMP_INGR',0x8562)
GL_GREEN_MAX_CLAMP_INGR=_C('GL_GREEN_MAX_CLAMP_INGR',0x8565)
GL_GREEN_MIN_CLAMP_INGR=_C('GL_GREEN_MIN_CLAMP_INGR',0x8561)
GL_RED_MAX_CLAMP_INGR=_C('GL_RED_MAX_CLAMP_INGR',0x8564)
GL_RED_MIN_CLAMP_INGR=_C('GL_RED_MIN_CLAMP_INGR',0x8560)




'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_KHR_stream_cross_process_fd'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_KHR_stream_cross_process_fd',error_checker=_errors._error_checker)
# EGL_NO_FILE_DESCRIPTOR_KHR=_C('EGL_NO_FILE_DESCRIPTOR_KHR',((EGLNativeFileDescriptorKHR)(-1)))
@_f
@_p.types(_cs.EGLStreamKHR,_cs.EGLDisplay,_cs.EGLNativeFileDescriptorKHR)
def eglCreateStreamFromFileDescriptorKHR(dpy,file_descriptor):pass
@_f
@_p.types(_cs.EGLNativeFileDescriptorKHR,_cs.EGLDisplay,_cs.EGLStreamKHR)
def eglGetStreamFileDescriptorKHR(dpy,stream):pass



'''OpenGL extension NV.DX_interop2

This module customises the behaviour of the 
OpenGL.raw.WGL.NV.DX_interop2 to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension expands on the specification of WGL_NV_DX_interop
	to add support for DirectX version 10, 10.1 and 11 resources.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/DX_interop2.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.WGL import _types, _glgets
from OpenGL.raw.WGL.NV.DX_interop2 import *
from OpenGL.raw.WGL.NV.DX_interop2 import _EXTENSION_NAME

def glInitDxInterop2NV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension AMD.seamless_cubemap_per_texture

This module customises the behaviour of the 
OpenGL.raw.GL.AMD.seamless_cubemap_per_texture to provide a more 
Python-friendly API

Overview (from the spec)
	
	In unextended OpenGL, cube maps are treated as sets of six, independent
	texture images. Once a face is selected from the set, it is treated exactly
	as any other two-dimensional texture would be. When sampling linearly from
	the texture, all of the individual texels that would be used to to create
	the final, bilinear sample values are taken from the same cube face. The
	normal, two-dimensional texture coordinate wrapping modes are honored.
	This sometimes causes seams to appear in cube maps.
	
	ARB_seamless_cube_map addresses this issue by providing a mechanism whereby
	an implementation could take each of the taps of a bilinear sample from
	a different face, spanning face boundaries and providing seamless filtering
	from cube map textures. However, in ARB_seamless_cube_map, this feature was
	exposed as a global state, affecting all bound cube map textures. It was not
	possible to mix seamless and per-face cube map sampling modes during
	multisampling. Furthermore, if an application included cube maps that were
	meant to be sampled seamlessly and non-seamlessly, it would have to track
	this state and enable or disable seamless cube map sampling as needed.
	
	This extension addresses this issue and provides an orthogonal method for
	allowing an implementation to provide a per-texture setting for enabling
	seamless sampling from cube maps.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/AMD/seamless_cubemap_per_texture.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.AMD.seamless_cubemap_per_texture import *
from OpenGL.raw.GL.AMD.seamless_cubemap_per_texture import _EXTENSION_NAME

def glInitSeamlessCubemapPerTextureAMD():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension SGIX.visual_select_group

This module customises the behaviour of the 
OpenGL.raw.GLX.SGIX.visual_select_group to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a mechanism to lower visual selection 
	priorities that glXChooseVisual or glXChooseFBConfig defines.  
	A new visual attribute is introduced, providing a way for servers
	to group visuals to different visual selection categories.
	The visual selection priorities of all the visuals in one category
	may be higher or lower than the ones in another category.  
	The visual selection priorities in one category follow the rules
	of glXChooseVisual or glXChooseFBConfig.  The new attribute is 
	invisible to users so can't be queried by glXGetConfig or 
	glXGetFBConfigAttrib.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/visual_select_group.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLX import _types, _glgets
from OpenGL.raw.GLX.SGIX.visual_select_group import *
from OpenGL.raw.GLX.SGIX.visual_select_group import _EXTENSION_NAME

def glInitVisualSelectGroupSGIX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_texture3D'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_texture3D',error_checker=_errors._error_checker)
GL_MAX_3D_TEXTURE_SIZE_EXT=_C('GL_MAX_3D_TEXTURE_SIZE_EXT',0x8073)
GL_PACK_IMAGE_HEIGHT_EXT=_C('GL_PACK_IMAGE_HEIGHT_EXT',0x806C)
GL_PACK_SKIP_IMAGES_EXT=_C('GL_PACK_SKIP_IMAGES_EXT',0x806B)
GL_PROXY_TEXTURE_3D_EXT=_C('GL_PROXY_TEXTURE_3D_EXT',0x8070)
GL_TEXTURE_3D_EXT=_C('GL_TEXTURE_3D_EXT',0x806F)
GL_TEXTURE_DEPTH_EXT=_C('GL_TEXTURE_DEPTH_EXT',0x8071)
GL_TEXTURE_WRAP_R_EXT=_C('GL_TEXTURE_WRAP_R_EXT',0x8072)
GL_UNPACK_IMAGE_HEIGHT_EXT=_C('GL_UNPACK_IMAGE_HEIGHT_EXT',0x806E)
GL_UNPACK_SKIP_IMAGES_EXT=_C('GL_UNPACK_SKIP_IMAGES_EXT',0x806D)
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLenum,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei,_cs.GLint,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glTexImage3DEXT(target,level,internalformat,width,height,depth,border,format,type,pixels):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glTexSubImage3DEXT(target,level,xoffset,yoffset,zoffset,width,height,depth,format,type,pixels):pass



'''OpenGL extension EXT.abgr

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.abgr to provide a more 
Python-friendly API

Overview (from the spec)
	
	EXT_abgr extends the list of host-memory color formats.  Specifically,
	it provides a reverse-order alternative to image format RGBA.  The ABGR
	component order matches the cpack Iris GL format on big-endian machines.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/abgr.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.abgr import *
from OpenGL.raw.GL.EXT.abgr import _EXTENSION_NAME

def glInitAbgrEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION
from OpenGL import images as _i

_i.COMPONENT_COUNTS[ GL_ABGR_EXT ] = 4



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_paletted_texture'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_paletted_texture',error_checker=_errors._error_checker)
GL_COLOR_INDEX12_EXT=_C('GL_COLOR_INDEX12_EXT',0x80E6)
GL_COLOR_INDEX16_EXT=_C('GL_COLOR_INDEX16_EXT',0x80E7)
GL_COLOR_INDEX1_EXT=_C('GL_COLOR_INDEX1_EXT',0x80E2)
GL_COLOR_INDEX2_EXT=_C('GL_COLOR_INDEX2_EXT',0x80E3)
GL_COLOR_INDEX4_EXT=_C('GL_COLOR_INDEX4_EXT',0x80E4)
GL_COLOR_INDEX8_EXT=_C('GL_COLOR_INDEX8_EXT',0x80E5)
GL_TEXTURE_INDEX_SIZE_EXT=_C('GL_TEXTURE_INDEX_SIZE_EXT',0x80ED)
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLsizei,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glColorTableEXT(target,internalFormat,width,format,type,table):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glGetColorTableEXT(target,format,type,data):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetColorTableParameterfvEXT(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetColorTableParameterivEXT(target,pname,params):pass



'''OpenGL extension ARB.framebuffer_object

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.framebuffer_object to provide a more 
Python-friendly API

Overview (from the spec)
	
	ARB_framebuffer_object is an extension intended to address the following
	goals:
	
	- Reflect FBO-related functionality found in the OpenGL 3.0 specification.
	
	- Integrate multiple disjoint extensions into a single ARB extension.
	  These extensions are:
	
	    EXT_framebuffer_object
	    EXT_framebuffer_blit
	    EXT_framebuffer_multisample
	    EXT_packed_depth_stencil    
	
	- Where appropriate, relax some of the constraints expressed by previous
	  FBO-related extensions. In particular the requirement of matching
	  attachment dimensions and component sizes has been relaxed, to allow
	  implementations the freedom to support more flexible usages where
	  possible.
	
	
	ARB_framebuffer_object defines an interface for drawing to rendering
	destinations other than the buffers provided to the GL by the
	window-system.
	
	In this extension, these newly defined rendering destinations are
	known collectively as "framebuffer-attachable images".  This
	extension provides a mechanism for attaching framebuffer-attachable
	images to the GL framebuffer as one of the standard GL logical
	buffers: color, depth, and stencil.  (Attaching a
	framebuffer-attachable image to the accum logical buffer is left for
	a future extension to define).  When a framebuffer-attachable image
	is attached to the framebuffer, it is used as the source and
	destination of fragment operations as described in Chapter 4.
	
	By allowing the use of a framebuffer-attachable image as a rendering
	destination, this extension enables a form of "offscreen" rendering.
	Furthermore, "render to texture" is supported by allowing the images
	of a texture to be used as framebuffer-attachable images.  A
	particular image of a texture object is selected for use as a
	framebuffer-attachable image by specifying the mipmap level, cube
	map face (for a cube map texture), and layer (for a 3D texture)
	that identifies the image.  The "render to texture" semantics of
	this extension are similar to performing traditional rendering to
	the framebuffer, followed immediately by a call to CopyTexSubImage.
	However, by using this extension instead, an application can achieve
	the same effect, but with the advantage that the GL can usually
	eliminate the data copy that would have been incurred by calling
	CopyTexSubImage.
	
	This extension also defines a new GL object type, called a
	"renderbuffer", which encapsulates a single 2D pixel image.  The
	image of renderbuffer can be used as a framebuffer-attachable image
	for generalized offscreen rendering and it also provides a means to
	support rendering to GL logical buffer types which have no
	corresponding texture format (stencil, accum, etc).  A renderbuffer
	is similar to a texture in that both renderbuffers and textures can
	be independently allocated and shared among multiple contexts.  The
	framework defined by this extension is general enough that support
	for attaching images from GL objects other than textures and
	renderbuffers could be added by layered extensions.
	
	To facilitate efficient switching between collections of
	framebuffer-attachable images, this extension introduces another new
	GL object, called a framebuffer object.  A framebuffer object
	contains the state that defines the traditional GL framebuffer,
	including its set of images.  Prior to this extension, it was the
	window-system which defined and managed this collection of images,
	traditionally by grouping them into a "drawable".  The window-system
	API's would also provide a function (i.e., wglMakeCurrent,
	glXMakeCurrent, aglSetDrawable, etc.) to bind a drawable with a GL
	context (as is done in the WGL_ARB_pbuffer extension).  In this
	extension however, this functionality is subsumed by the GL and the
	GL provides the function BindFramebufferARB to bind a framebuffer
	object to the current context.  Later, the context can bind back to
	the window-system-provided framebuffer in order to display rendered
	content.
	
	Previous extensions that enabled rendering to a texture have been
	much more complicated.  One example is the combination of
	ARB_pbuffer and ARB_render_texture, both of which are window-system
	extensions.  This combination requires calling MakeCurrent, an
	operation that may be expensive, to switch between the window and
	the pbuffer drawables.  An application must create one pbuffer per
	renderable texture in order to portably use ARB_render_texture.  An
	application must maintain at least one GL context per texture
	format, because each context can only operate on a single
	pixelformat or FBConfig.  All of these characteristics make
	ARB_render_texture both inefficient and cumbersome to use.
	
	ARB_framebuffer_object, on the other hand, is both simpler to use
	and more efficient than ARB_render_texture.  The
	ARB_framebuffer_object API is contained wholly within the GL API and
	has no (non-portable) window-system components.  Under
	ARB_framebuffer_object, it is not necessary to create a second GL
	context when rendering to a texture image whose format differs from
	that of the window.  Finally, unlike the pbuffers of
	ARB_render_texture, a single framebuffer object can facilitate
	rendering to an unlimited number of texture objects.
	
	This extension differs from EXT_framebuffer_object by splitting the
	framebuffer object binding point into separate DRAW and READ
	bindings (incorporating functionality introduced by
	EXT_framebuffer_blit). This allows copying directly from one
	framebuffer to another. In addition, a new high performance blit
	function is added to facilitate these blits and perform some data
	conversion where allowed.
	
	This extension also enables usage of multisampling in conjunction with
	renderbuffers (incorporating functionality from
	EXT_packed_depth_stencil), as follows:
	
	The new operation RenderbufferStorageMultisample() allocates
	storage for a renderbuffer object that can be used as a multisample
	buffer.  A multisample render buffer image differs from a
	single-sample render buffer image in that a multisample image has a
	number of SAMPLES that is greater than zero.  No method is provided
	for creating multisample texture images.
	
	All of the framebuffer-attachable images attached to a framebuffer
	object must have the same number of SAMPLES or else the framebuffer
	object is not "framebuffer complete".  If a framebuffer object with
	multisample attachments is "framebuffer complete", then the
	framebuffer object behaves as if SAMPLE_BUFFERS is one.
	
	In traditional multisample rendering, where
	DRAW_FRAMEBUFFER_BINDING is zero and SAMPLE_BUFFERS is one, the
	GL spec states that "the color sample values are resolved to a
	single, displayable color each time a pixel is updated."  There are,
	however, several modern hardware implementations that do not
	actually resolve for each sample update, but instead postpones the
	resolve operation to a later time and resolve a batch of sample
	updates at a time.  This is OK as long as the implementation behaves
	"as if" it had resolved a sample-at-a-time. Unfortunately, however,
	honoring the "as if" rule can sometimes degrade performance.
	
	In contrast, when DRAW_FRAMEBUFFER_BINDING is an
	application-created framebuffer object, MULTISAMPLE is enabled, and
	SAMPLE_BUFFERS is one, there is no implicit per-sample-update
	resolve.  Instead, the application explicitly controls when the
	resolve operation is performed.  The resolve operation is affected
	by calling BlitFramebuffer where the source is a multisample
	application-created framebuffer object and the destination is a 
	single-sample framebuffer object (either application-created or 
	window-system provided).
	
	This design for multisample resolve more closely matches current
	hardware, but still permits implementations which choose to resolve
	a single sample at a time.  If hardware that implements the
	multisample resolution "one sample at a time" exposes
	ARB_framebuffer_object, it could perform the implicit resolve
	to a driver-managed hidden surface, then read from that surface when
	the application calls BlitFramebuffer.
	
	Another motivation for granting the application explicit control
	over the multisample resolve operation has to do with the
	flexibility afforded by ARB_framebuffer_object.  Previously, a
	drawable (window or pbuffer) had exclusive access to all of its
	buffers.  There was no mechanism for sharing a buffer across
	multiple drawables.  Under ARB_framebuffer_object, however, a
	mechanism exists for sharing a framebuffer-attachable image across
	several framebuffer objects, as well as sharing an image between a
	framebuffer object and a texture.  If we had retained the "implicit"
	resolve from traditional multisampled rendering, and allowed the
	creation of "multisample" format renderbuffers, then this type of
	sharing would have lead to two problematic situations:
	
	  * Two contexts, which shared renderbuffers, might perform
	    competing resolve operations into the same single-sample buffer
	    with ambiguous results.
	
	  * It would have introduced the unfortunate ability to use the
	    single-sample buffer as a texture while MULTISAMPLE is ENABLED.
	
	Using BlitFramebuffer as an explicit resolve to serialize access to
	the multisampled contents and eliminate the implicit per-sample
	resolve operation, we avoid both of these problems.
	
	This extension also enables usage of packed depth-stencil formats in 
	renderbuffers (incorporating functionality from
	EXT_packed_depth_stencil), as follows:
	
	Many OpenGL implementations have chosen to interleave the depth and
	stencil buffers into one buffer, often with 24 bits of depth
	precision and 8 bits of stencil data.  32 bits is more than is
	needed for the depth buffer much of the time; a 24-bit depth buffer,
	on the other hand, requires that reads and writes of depth data be
	unaligned with respect to power-of-two boundaries.  On the other
	hand, 8 bits of stencil data is more than sufficient for most
	applications, so it is only natural to pack the two buffers into a
	single buffer with both depth and stencil data.  OpenGL never
	provides direct access to the buffers, so the OpenGL implementation
	can provide an interface to applications where it appears the one
	merged buffer is composed of two logical buffers.
	
	One disadvantage of this scheme is that OpenGL lacks any means by
	which this packed data can be handled efficiently.  For example,
	when an application reads from the 24-bit depth buffer, using the
	type GL_UNSIGNED_SHORT will lose 8 bits of data, while
	GL_UNSIGNED_INT has 8 too many.  Both require expensive format
	conversion operations.  A 24-bit format would be no more suitable,
	because it would also suffer from the unaligned memory accesses that
	made the standalone 24-bit depth buffer an unattractive proposition
	in the first place.
	
	Many applications, such as parallel rendering applications, may also
	wish to draw to or read back from both the depth and stencil buffers
	at the same time.  Currently this requires two separate operations,
	reducing performance.  Since the buffers are interleaved, drawing to
	or reading from both should be no more expensive than using just
	one; in some cases, it may even be cheaper.
	
	This extension provides a new data format, GL_DEPTH_STENCIL,
	that can be used with the glDrawPixels, glReadPixels, and
	glCopyPixels commands, as well as a packed data type,
	GL_UNSIGNED_INT_24_8, that is meant to be used with
	GL_DEPTH_STENCIL.  No other data types are supported with
	GL_DEPTH_STENCIL.  If ARB_depth_texture or SGIX_depth_texture is
	supported, GL_DEPTH_STENCIL/GL_UNSIGNED_INT_24_8 data can
	also be used for textures; this provides a more efficient way to
	supply data for a 24-bit depth texture.
	
	GL_DEPTH_STENCIL data, when passed through the pixel path,
	undergoes both depth and stencil operations.  The depth data is
	scaled and biased by the current GL_DEPTH_SCALE and GL_DEPTH_BIAS,
	while the stencil data is shifted and offset by the current
	GL_INDEX_SHIFT and GL_INDEX_OFFSET.  The stencil data is also put
	through the stencil-to-stencil pixel map.
	
	glDrawPixels of GL_DEPTH_STENCIL data operates similarly to that
	of GL_STENCIL_INDEX data, bypassing the OpenGL fragment pipeline
	entirely, unlike the treatment of GL_DEPTH_COMPONENT data.  The
	stencil and depth masks are applied, as are the pixel ownership and
	scissor tests, but all other operations are skipped.
	
	glReadPixels of GL_DEPTH_STENCIL data reads back a rectangle
	from both the depth and stencil buffers.
	
	glCopyPixels of GL_DEPTH_STENCIL data copies a rectangle from
	both the depth and stencil buffers.  Like glDrawPixels, it applies
	both the stencil and depth masks but skips the remainder of the
	OpenGL fragment pipeline.
	
	glTex[Sub]Image[1,2,3]D of GL_DEPTH_STENCIL data loads depth and
	stencil data into a depth_stencil texture.  glGetTexImage of
	GL_DEPTH_STENCIL data can be used to retrieve depth and stencil
	data from a depth/stencil texture.
	
	In addition, a new base internal format, GL_DEPTH_STENCIL, can
	be used by both texture images and renderbuffer storage.  When an
	image with a DEPTH_STENCIL internal format is attached to both
	the depth and stencil attachment points of a framebuffer object, 
	then it becomes both the depth and stencil
	buffers of the framebuffer.  This fits nicely with hardware that
	interleaves both depth and stencil data into a single buffer.  When
	a texture with DEPTH_STENCIL data is bound for texturing, only
	the depth component is accessible through the texture fetcher.  The
	stencil data can be written with TexImage or CopyTexImage, and can
	be read with GetTexImage.  When a DEPTH_STENCIL image is
	attached to the stencil attachment of the bound framebuffer object,
	the stencil data can be accessed through any operation that reads
	from or writes to the framebuffer's stencil buffer.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/framebuffer_object.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.framebuffer_object import *
from OpenGL.raw.GL.ARB.framebuffer_object import _EXTENSION_NAME

def glInitFramebufferObjectARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glDeleteRenderbuffers.renderbuffers size not checked against n
glDeleteRenderbuffers=wrapper.wrapper(glDeleteRenderbuffers).setInputArraySize(
    'renderbuffers', None
)
glGenRenderbuffers=wrapper.wrapper(glGenRenderbuffers).setOutput(
    'renderbuffers',size=lambda x:(x,),pnameArg='n',orPassIn=True
)
glGetRenderbufferParameteriv=wrapper.wrapper(glGetRenderbufferParameteriv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
# INPUT glDeleteFramebuffers.framebuffers size not checked against n
glDeleteFramebuffers=wrapper.wrapper(glDeleteFramebuffers).setInputArraySize(
    'framebuffers', None
)
glGenFramebuffers=wrapper.wrapper(glGenFramebuffers).setOutput(
    'framebuffers',size=lambda x:(x,),pnameArg='n',orPassIn=True
)
glGetFramebufferAttachmentParameteriv=wrapper.wrapper(glGetFramebufferAttachmentParameteriv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
### END AUTOGENERATED SECTION
from OpenGL.lazywrapper import lazy as _lazy 

glGenFramebuffers = wrapper.wrapper(glGenFramebuffers).setOutput(
                'framebuffers', 
                lambda x: (x,), 
                'n', orPassIn=True)
                
glGenRenderbuffers = wrapper.wrapper(glGenRenderbuffers).setOutput(
                'renderbuffers', 
                lambda x: (x,), 
                'n', orPassIn=True)


@_lazy( glDeleteFramebuffers )
def glDeleteFramebuffers( baseOperation, n, framebuffers=None ):
    """glDeleteFramebuffers( framebuffers ) -> None 
    """
    if framebuffers is None:
        framebuffers = arrays.GLuintArray.asArray( n )
        n = arrays.GLuintArray.arraySize( framebuffers )
    return baseOperation( n, framebuffers )

# Setup the GL_UNSIGNED_INT_24_8 image type
from OpenGL import images
from OpenGL.raw.GL.VERSION.GL_1_1 import GL_UNSIGNED_INT
images.TYPE_TO_ARRAYTYPE[ GL_UNSIGNED_INT_24_8 ] = GL_UNSIGNED_INT
images.TIGHT_PACK_FORMATS[ GL_UNSIGNED_INT_24_8 ] = 4

# The extensions actually use the _EXT forms, which is a bit confusing 
# for users, IMO.
GL_FRAMEBUFFER_INCOMPLETE_DIMENSIONS = constant.Constant( 'GL_FRAMEBUFFER_INCOMPLETE_DIMENSIONS', 0x8CD9 )
GL_FRAMEBUFFER_INCOMPLETE_FORMATS = constant.Constant( 'GL_FRAMEBUFFER_INCOMPLETE_FORMATS', 0x8CDA )
GL_FRAMEBUFFER_UNSUPPORTED = constant.Constant( 'GL_FRAMEBUFFER_UNSUPPORTED', 0x8CDD )
del images 
del GL_UNSIGNED_INT



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_EXT_pvrtc_sRGB'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_EXT_pvrtc_sRGB',error_checker=_errors._error_checker)
GL_COMPRESSED_SRGB_ALPHA_PVRTC_2BPPV1_EXT=_C('GL_COMPRESSED_SRGB_ALPHA_PVRTC_2BPPV1_EXT',0x8A56)
GL_COMPRESSED_SRGB_ALPHA_PVRTC_2BPPV2_IMG=_C('GL_COMPRESSED_SRGB_ALPHA_PVRTC_2BPPV2_IMG',0x93F0)
GL_COMPRESSED_SRGB_ALPHA_PVRTC_4BPPV1_EXT=_C('GL_COMPRESSED_SRGB_ALPHA_PVRTC_4BPPV1_EXT',0x8A57)
GL_COMPRESSED_SRGB_ALPHA_PVRTC_4BPPV2_IMG=_C('GL_COMPRESSED_SRGB_ALPHA_PVRTC_4BPPV2_IMG',0x93F1)
GL_COMPRESSED_SRGB_PVRTC_2BPPV1_EXT=_C('GL_COMPRESSED_SRGB_PVRTC_2BPPV1_EXT',0x8A54)
GL_COMPRESSED_SRGB_PVRTC_4BPPV1_EXT=_C('GL_COMPRESSED_SRGB_PVRTC_4BPPV1_EXT',0x8A55)




'''OpenGL extension SGIX.fog_offset

This module customises the behaviour of the 
OpenGL.raw.GL.SGIX.fog_offset to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows fragments to look brighter in a foggy
	environment, by biasing the fragment eye-coordinate distance prior
	to fog computation. A reference point in eye space (rx ry rz) and an offset
	amount toward the viewpoint (f_o) are specified. When fog offset is
	enabled, the offset amount will be subtracted from the fragment
	distance, making objects appear less foggy.
	
	If fog computation is done in screen-space coordinates under
	perspective projection, the reference point is used in adjusting the
	fog offset to be correct for fragments whose depth is close to that
	point. The reference point should be redefined when it becomes too
	far away from the primitives being drawn. Under orthographic
	projection, or if fog computation is done in eye-space coordinates,
	the reference point is ignored.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/fog_offset.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIX.fog_offset import *
from OpenGL.raw.GL.SGIX.fog_offset import _EXTENSION_NAME

def glInitFogOffsetSGIX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.pixel_buffer_object

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.pixel_buffer_object to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension expands on the interface provided by buffer objects.
	It is intended to permit buffer objects to be used not only with 
	vertex array data, but also with pixel data.
	Buffer objects were promoted from the ARB_vertex_buffer_object
	extension in OpenGL 1.5.
	
	Recall that buffer objects conceptually are nothing more than arrays
	of bytes, just like any chunk of memory. Buffer objects allow GL
	commands to source data from a buffer object by binding the buffer
	object to a given target and then overloading a certain set of GL
	commands' pointer arguments to refer to offsets inside the buffer,
	rather than pointers to user memory.  An offset is encoded in a
	pointer by adding the offset to a null pointer.
	
	This extension does not add any new functionality to buffer
	objects themselves.  It simply adds two new targets to which buffer
	objects can be bound: PIXEL_PACK_BUFFER and PIXEL_UNPACK_BUFFER.
	When a buffer object is bound to the PIXEL_PACK_BUFFER target,
	commands such as ReadPixels write their data into a buffer object.
	When a buffer object is bound to the PIXEL_UNPACK_BUFFER target,
	commands such as DrawPixels read their data from a buffer object.
	
	There are a wide variety of applications for such functionality.
	Some of the most interesting ones are:
	
	- "Render to vertex array."  The application can use a fragment
	  program to render some image into one of its buffers, then read
	  this image out into a buffer object via ReadPixels.  Then, it can
	  use this buffer object as a source of vertex data.
	
	- Streaming textures.  If the application uses MapBuffer/UnmapBuffer
	  to write its data for TexSubImage into a buffer object, at least
	  one of the data copies usually required to download a texture can
	  be eliminated, significantly increasing texture download
	  performance.
	
	- Asynchronous ReadPixels.  If an application needs to read back a
	  number of images and process them with the CPU, the existing GL
	  interface makes it nearly impossible to pipeline this operation.
	  The driver will typically send the hardware a readback command
	  when ReadPixels is called, and then wait for all of the data to
	  be available before returning control to the application.  Then,
	  the application can either process the data immediately or call
	  ReadPixels again; in neither case will the readback overlap with
	  the processing.  If the application issues several readbacks into
	  several buffer objects, however, and then maps each one to process
	  its data, then the readbacks can proceed in parallel with the data
	  processing.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/pixel_buffer_object.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.pixel_buffer_object import *
from OpenGL.raw.GL.EXT.pixel_buffer_object import _EXTENSION_NAME

def glInitPixelBufferObjectEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension SGIX.swap_group

This module customises the behaviour of the 
OpenGL.raw.GLX.SGIX.swap_group to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides the capability to synchronize the buffer swaps
	of a group of GLX drawables.  A swap group is created, and drawables are 
	added as members to the swap group.  Buffer swaps to members of the swap 
	group will then take place concurrently.
	
	This extension extends the set of conditions that must be met before
	a buffer swap can take place. 

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/swap_group.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLX import _types, _glgets
from OpenGL.raw.GLX.SGIX.swap_group import *
from OpenGL.raw.GLX.SGIX.swap_group import _EXTENSION_NAME

def glInitSwapGroupSGIX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_SGIS_multisample'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_SGIS_multisample',error_checker=_errors._error_checker)
GL_1PASS_SGIS=_C('GL_1PASS_SGIS',0x80A1)
GL_2PASS_0_SGIS=_C('GL_2PASS_0_SGIS',0x80A2)
GL_2PASS_1_SGIS=_C('GL_2PASS_1_SGIS',0x80A3)
GL_4PASS_0_SGIS=_C('GL_4PASS_0_SGIS',0x80A4)
GL_4PASS_1_SGIS=_C('GL_4PASS_1_SGIS',0x80A5)
GL_4PASS_2_SGIS=_C('GL_4PASS_2_SGIS',0x80A6)
GL_4PASS_3_SGIS=_C('GL_4PASS_3_SGIS',0x80A7)
GL_MULTISAMPLE_SGIS=_C('GL_MULTISAMPLE_SGIS',0x809D)
GL_SAMPLES_SGIS=_C('GL_SAMPLES_SGIS',0x80A9)
GL_SAMPLE_ALPHA_TO_MASK_SGIS=_C('GL_SAMPLE_ALPHA_TO_MASK_SGIS',0x809E)
GL_SAMPLE_ALPHA_TO_ONE_SGIS=_C('GL_SAMPLE_ALPHA_TO_ONE_SGIS',0x809F)
GL_SAMPLE_BUFFERS_SGIS=_C('GL_SAMPLE_BUFFERS_SGIS',0x80A8)
GL_SAMPLE_MASK_INVERT_SGIS=_C('GL_SAMPLE_MASK_INVERT_SGIS',0x80AB)
GL_SAMPLE_MASK_SGIS=_C('GL_SAMPLE_MASK_SGIS',0x80A0)
GL_SAMPLE_MASK_VALUE_SGIS=_C('GL_SAMPLE_MASK_VALUE_SGIS',0x80AA)
GL_SAMPLE_PATTERN_SGIS=_C('GL_SAMPLE_PATTERN_SGIS',0x80AC)
@_f
@_p.types(None,_cs.GLclampf,_cs.GLboolean)
def glSampleMaskSGIS(value,invert):pass
@_f
@_p.types(None,_cs.GLenum)
def glSamplePatternSGIS(pattern):pass



'''OpenGL extension EXT.geometry_shader4

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.geometry_shader4 to provide a more 
Python-friendly API

Overview (from the spec)
	
	EXT_geometry_shader4 defines a new shader type available to be run on the
	GPU, called a geometry shader. Geometry shaders are run after vertices are
	transformed, but prior to color clamping, flat shading and clipping.
	
	A geometry shader begins with a single primitive (point, line,
	triangle). It can read the attributes of any of the vertices in the
	primitive and use them to generate new primitives. A geometry shader has a
	fixed output primitive type (point, line strip, or triangle strip) and
	emits vertices to define a new primitive. A geometry shader can emit
	multiple disconnected primitives. The primitives emitted by the geometry
	shader are clipped and then processed like an equivalent OpenGL primitive
	specified by the application.
	
	Furthermore, EXT_geometry_shader4 provides four additional primitive
	types: lines with adjacency, line strips with adjacency, separate
	triangles with adjacency, and triangle strips with adjacency.  Some of the
	vertices specified in these new primitive types are not part of the
	ordinary primitives, instead they represent neighboring vertices that are
	adjacent to the two line segment end points (lines/strips) or the three
	triangle edges (triangles/tstrips). These vertices can be accessed by
	geometry shaders and used to match up the vertices emitted by the geometry
	shader with those of neighboring primitives.
	
	Since geometry shaders expect a specific input primitive type, an error
	will occur if the application presents primitives of a different type.
	For example, if a geometry shader expects points, an error will occur at
	Begin() time, if a primitive mode of TRIANGLES is specified.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/geometry_shader4.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.geometry_shader4 import *
from OpenGL.raw.GL.EXT.geometry_shader4 import _EXTENSION_NAME

def glInitGeometryShader4EXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_index_material'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_index_material',error_checker=_errors._error_checker)
GL_INDEX_MATERIAL_EXT=_C('GL_INDEX_MATERIAL_EXT',0x81B8)
GL_INDEX_MATERIAL_FACE_EXT=_C('GL_INDEX_MATERIAL_FACE_EXT',0x81BA)
GL_INDEX_MATERIAL_PARAMETER_EXT=_C('GL_INDEX_MATERIAL_PARAMETER_EXT',0x81B9)
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum)
def glIndexMaterialEXT(face,mode):pass



'''OpenGL extension NV.fog_distance

This module customises the behaviour of the 
OpenGL.raw.GL.NV.fog_distance to provide a more 
Python-friendly API

Overview (from the spec)
	
	Ideally, the fog distance (used to compute the fog factor as
	described in Section 3.10) should be computed as the per-fragment
	Euclidean distance to the fragment center from the eye.  In practice,
	implementations "may choose to approximate the eye-coordinate
	distance from the eye to each fragment center by abs(ze).  Further,
	[the fog factor] f need not be computed at each fragment, but may
	be computed at each vertex and interpolated as other data are."
	
	This extension provides the application specific control over how
	OpenGL computes the distance used in computing the fog factor.
	
	The extension supports three fog distance modes: "eye plane absolute",
	where the fog distance is the absolute planar distance from the eye
	plane (i.e., OpenGL's standard implementation allowance as cited above);
	"eye plane", where the fog distance is the signed planar distance
	from the eye plane; and "eye radial", where the fog distance is
	computed as a Euclidean distance.  In the case of the eye radial
	fog distance mode, the distance may be computed per-vertex and then
	interpolated per-fragment.
	
	The intent of this extension is to provide applications with better
	control over the tradeoff between performance and fog quality.
	The "eye planar" modes (signed or absolute) are straightforward
	to implement with good performance, but scenes are consistently
	under-fogged at the edges of the field of view.  The "eye radial"
	mode can provide for more accurate fog at the edges of the field of
	view, but this assumes that either the eye radial fog distance is
	computed per-fragment, or if the fog distance is computed per-vertex
	and then interpolated per-fragment, then the scene must be
	sufficiently tessellated.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/fog_distance.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.fog_distance import *
from OpenGL.raw.GL.NV.fog_distance import _EXTENSION_NAME

def glInitFogDistanceNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.texture_array

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.texture_array to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension introduces the notion of one- and two-dimensional array
	textures.  An array texture is a collection of one- and two-dimensional
	images of identical size and format, arranged in layers.  A
	one-dimensional array texture is specified using TexImage2D; a
	two-dimensional array texture is specified using TexImage3D.  The height
	(1D array) or depth (2D array) specify the number of layers in the image.
	
	An array texture is accessed as a single unit in a programmable shader,
	using a single coordinate vector.  A single layer is selected, and that
	layer is then accessed as though it were a one- or two-dimensional
	texture.  The layer used is specified using the "t" or "r" texture
	coordinate for 1D and 2D array textures, respectively.  The layer
	coordinate is provided as an unnormalized floating-point value in the
	range [0,<n>-1], where <n> is the number of layers in the array texture.
	Texture lookups do not filter between layers, though such filtering can be
	achieved using programmable shaders.  When mipmapping is used, each level
	of an array texture has the same number of layers as the base level; the
	number of layers is not reduced as the image size decreases.
	
	Array textures can be rendered to by binding them to a framebuffer object
	(EXT_framebuffer_object).  A single layer of an array texture can be bound
	using normal framebuffer object mechanisms, or an entire array texture can
	be bound and rendered to using the layered rendering mechanisms provided
	by NV_geometry_program4.
	
	This extension does not provide for the use of array textures with
	fixed-function fragment processing.  Such support could be added by
	providing an additional extension allowing applications to pass the new
	target enumerants (TEXTURE_1D_ARRAY_EXT and TEXTURE_2D_ARRAY_EXT) to
	Enable and Disable.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/texture_array.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.texture_array import *
from OpenGL.raw.GL.EXT.texture_array import _EXTENSION_NAME

def glInitTextureArrayEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_framebuffer_object'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_framebuffer_object',error_checker=_errors._error_checker)
GL_COLOR_ATTACHMENT0=_C('GL_COLOR_ATTACHMENT0',0x8CE0)
GL_COLOR_ATTACHMENT1=_C('GL_COLOR_ATTACHMENT1',0x8CE1)
GL_COLOR_ATTACHMENT10=_C('GL_COLOR_ATTACHMENT10',0x8CEA)
GL_COLOR_ATTACHMENT11=_C('GL_COLOR_ATTACHMENT11',0x8CEB)
GL_COLOR_ATTACHMENT12=_C('GL_COLOR_ATTACHMENT12',0x8CEC)
GL_COLOR_ATTACHMENT13=_C('GL_COLOR_ATTACHMENT13',0x8CED)
GL_COLOR_ATTACHMENT14=_C('GL_COLOR_ATTACHMENT14',0x8CEE)
GL_COLOR_ATTACHMENT15=_C('GL_COLOR_ATTACHMENT15',0x8CEF)
GL_COLOR_ATTACHMENT2=_C('GL_COLOR_ATTACHMENT2',0x8CE2)
GL_COLOR_ATTACHMENT3=_C('GL_COLOR_ATTACHMENT3',0x8CE3)
GL_COLOR_ATTACHMENT4=_C('GL_COLOR_ATTACHMENT4',0x8CE4)
GL_COLOR_ATTACHMENT5=_C('GL_COLOR_ATTACHMENT5',0x8CE5)
GL_COLOR_ATTACHMENT6=_C('GL_COLOR_ATTACHMENT6',0x8CE6)
GL_COLOR_ATTACHMENT7=_C('GL_COLOR_ATTACHMENT7',0x8CE7)
GL_COLOR_ATTACHMENT8=_C('GL_COLOR_ATTACHMENT8',0x8CE8)
GL_COLOR_ATTACHMENT9=_C('GL_COLOR_ATTACHMENT9',0x8CE9)
GL_DEPTH24_STENCIL8=_C('GL_DEPTH24_STENCIL8',0x88F0)
GL_DEPTH_ATTACHMENT=_C('GL_DEPTH_ATTACHMENT',0x8D00)
GL_DEPTH_STENCIL=_C('GL_DEPTH_STENCIL',0x84F9)
GL_DEPTH_STENCIL_ATTACHMENT=_C('GL_DEPTH_STENCIL_ATTACHMENT',0x821A)
GL_DRAW_FRAMEBUFFER=_C('GL_DRAW_FRAMEBUFFER',0x8CA9)
GL_DRAW_FRAMEBUFFER_BINDING=_C('GL_DRAW_FRAMEBUFFER_BINDING',0x8CA6)
GL_FRAMEBUFFER=_C('GL_FRAMEBUFFER',0x8D40)
GL_FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE=_C('GL_FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE',0x8215)
GL_FRAMEBUFFER_ATTACHMENT_BLUE_SIZE=_C('GL_FRAMEBUFFER_ATTACHMENT_BLUE_SIZE',0x8214)
GL_FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING=_C('GL_FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING',0x8210)
GL_FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE=_C('GL_FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE',0x8211)
GL_FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE=_C('GL_FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE',0x8216)
GL_FRAMEBUFFER_ATTACHMENT_GREEN_SIZE=_C('GL_FRAMEBUFFER_ATTACHMENT_GREEN_SIZE',0x8213)
GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME=_C('GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME',0x8CD1)
GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE=_C('GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE',0x8CD0)
GL_FRAMEBUFFER_ATTACHMENT_RED_SIZE=_C('GL_FRAMEBUFFER_ATTACHMENT_RED_SIZE',0x8212)
GL_FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE=_C('GL_FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE',0x8217)
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE=_C('GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE',0x8CD3)
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER=_C('GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER',0x8CD4)
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL=_C('GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL',0x8CD2)
GL_FRAMEBUFFER_BINDING=_C('GL_FRAMEBUFFER_BINDING',0x8CA6)
GL_FRAMEBUFFER_COMPLETE=_C('GL_FRAMEBUFFER_COMPLETE',0x8CD5)
GL_FRAMEBUFFER_DEFAULT=_C('GL_FRAMEBUFFER_DEFAULT',0x8218)
GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT=_C('GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT',0x8CD6)
GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER=_C('GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER',0x8CDB)
GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT=_C('GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT',0x8CD7)
GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE=_C('GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE',0x8D56)
GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER=_C('GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER',0x8CDC)
GL_FRAMEBUFFER_UNDEFINED=_C('GL_FRAMEBUFFER_UNDEFINED',0x8219)
GL_FRAMEBUFFER_UNSUPPORTED=_C('GL_FRAMEBUFFER_UNSUPPORTED',0x8CDD)
GL_INDEX=_C('GL_INDEX',0x8222)
GL_INVALID_FRAMEBUFFER_OPERATION=_C('GL_INVALID_FRAMEBUFFER_OPERATION',0x0506)
GL_MAX_COLOR_ATTACHMENTS=_C('GL_MAX_COLOR_ATTACHMENTS',0x8CDF)
GL_MAX_RENDERBUFFER_SIZE=_C('GL_MAX_RENDERBUFFER_SIZE',0x84E8)
GL_MAX_SAMPLES=_C('GL_MAX_SAMPLES',0x8D57)
GL_READ_FRAMEBUFFER=_C('GL_READ_FRAMEBUFFER',0x8CA8)
GL_READ_FRAMEBUFFER_BINDING=_C('GL_READ_FRAMEBUFFER_BINDING',0x8CAA)
GL_RENDERBUFFER=_C('GL_RENDERBUFFER',0x8D41)
GL_RENDERBUFFER_ALPHA_SIZE=_C('GL_RENDERBUFFER_ALPHA_SIZE',0x8D53)
GL_RENDERBUFFER_BINDING=_C('GL_RENDERBUFFER_BINDING',0x8CA7)
GL_RENDERBUFFER_BLUE_SIZE=_C('GL_RENDERBUFFER_BLUE_SIZE',0x8D52)
GL_RENDERBUFFER_DEPTH_SIZE=_C('GL_RENDERBUFFER_DEPTH_SIZE',0x8D54)
GL_RENDERBUFFER_GREEN_SIZE=_C('GL_RENDERBUFFER_GREEN_SIZE',0x8D51)
GL_RENDERBUFFER_HEIGHT=_C('GL_RENDERBUFFER_HEIGHT',0x8D43)
GL_RENDERBUFFER_INTERNAL_FORMAT=_C('GL_RENDERBUFFER_INTERNAL_FORMAT',0x8D44)
GL_RENDERBUFFER_RED_SIZE=_C('GL_RENDERBUFFER_RED_SIZE',0x8D50)
GL_RENDERBUFFER_SAMPLES=_C('GL_RENDERBUFFER_SAMPLES',0x8CAB)
GL_RENDERBUFFER_STENCIL_SIZE=_C('GL_RENDERBUFFER_STENCIL_SIZE',0x8D55)
GL_RENDERBUFFER_WIDTH=_C('GL_RENDERBUFFER_WIDTH',0x8D42)
GL_STENCIL_ATTACHMENT=_C('GL_STENCIL_ATTACHMENT',0x8D20)
GL_STENCIL_INDEX1=_C('GL_STENCIL_INDEX1',0x8D46)
GL_STENCIL_INDEX16=_C('GL_STENCIL_INDEX16',0x8D49)
GL_STENCIL_INDEX4=_C('GL_STENCIL_INDEX4',0x8D47)
GL_STENCIL_INDEX8=_C('GL_STENCIL_INDEX8',0x8D48)
GL_TEXTURE_STENCIL_SIZE=_C('GL_TEXTURE_STENCIL_SIZE',0x88F1)
GL_UNSIGNED_INT_24_8=_C('GL_UNSIGNED_INT_24_8',0x84FA)
GL_UNSIGNED_NORMALIZED=_C('GL_UNSIGNED_NORMALIZED',0x8C17)
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glBindFramebuffer(target,framebuffer):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glBindRenderbuffer(target,renderbuffer):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLbitfield,_cs.GLenum)
def glBlitFramebuffer(srcX0,srcY0,srcX1,srcY1,dstX0,dstY0,dstX1,dstY1,mask,filter):pass
@_f
@_p.types(_cs.GLenum,_cs.GLenum)
def glCheckFramebufferStatus(target):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteFramebuffers(n,framebuffers):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteRenderbuffers(n,renderbuffers):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLuint)
def glFramebufferRenderbuffer(target,attachment,renderbuffertarget,renderbuffer):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLint)
def glFramebufferTexture1D(target,attachment,textarget,texture,level):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLint)
def glFramebufferTexture2D(target,attachment,textarget,texture,level):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLint,_cs.GLint)
def glFramebufferTexture3D(target,attachment,textarget,texture,level,zoffset):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLint,_cs.GLint)
def glFramebufferTextureLayer(target,attachment,texture,level,layer):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenFramebuffers(n,framebuffers):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenRenderbuffers(n,renderbuffers):pass
@_f
@_p.types(None,_cs.GLenum)
def glGenerateMipmap(target):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetFramebufferAttachmentParameteriv(target,attachment,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetRenderbufferParameteriv(target,pname,params):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsFramebuffer(framebuffer):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsRenderbuffer(renderbuffer):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLsizei,_cs.GLsizei)
def glRenderbufferStorage(target,internalformat,width,height):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,_cs.GLenum,_cs.GLsizei,_cs.GLsizei)
def glRenderbufferStorageMultisample(target,samples,internalformat,width,height):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES1 import _types as _cs
# End users want this...
from OpenGL.raw.GLES1._types import *
from OpenGL.raw.GLES1 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES1_QCOM_extended_get'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES1,'GLES1_QCOM_extended_get',error_checker=_errors._error_checker)
GL_STATE_RESTORE=_C('GL_STATE_RESTORE',0x8BDC)
GL_TEXTURE_DEPTH_QCOM=_C('GL_TEXTURE_DEPTH_QCOM',0x8BD4)
GL_TEXTURE_FORMAT_QCOM=_C('GL_TEXTURE_FORMAT_QCOM',0x8BD6)
GL_TEXTURE_HEIGHT_QCOM=_C('GL_TEXTURE_HEIGHT_QCOM',0x8BD3)
GL_TEXTURE_IMAGE_VALID_QCOM=_C('GL_TEXTURE_IMAGE_VALID_QCOM',0x8BD8)
GL_TEXTURE_INTERNAL_FORMAT_QCOM=_C('GL_TEXTURE_INTERNAL_FORMAT_QCOM',0x8BD5)
GL_TEXTURE_NUM_LEVELS_QCOM=_C('GL_TEXTURE_NUM_LEVELS_QCOM',0x8BD9)
GL_TEXTURE_OBJECT_VALID_QCOM=_C('GL_TEXTURE_OBJECT_VALID_QCOM',0x8BDB)
GL_TEXTURE_TARGET_QCOM=_C('GL_TEXTURE_TARGET_QCOM',0x8BDA)
GL_TEXTURE_TYPE_QCOM=_C('GL_TEXTURE_TYPE_QCOM',0x8BD7)
GL_TEXTURE_WIDTH_QCOM=_C('GL_TEXTURE_WIDTH_QCOM',0x8BD2)
@_f
@_p.types(None,_cs.GLenum,arrays.GLvoidpArray)
def glExtGetBufferPointervQCOM(target,params):pass
@_f
@_p.types(None,arrays.GLuintArray,_cs.GLint,arrays.GLintArray)
def glExtGetBuffersQCOM(buffers,maxBuffers,numBuffers):pass
@_f
@_p.types(None,arrays.GLuintArray,_cs.GLint,arrays.GLintArray)
def glExtGetFramebuffersQCOM(framebuffers,maxFramebuffers,numFramebuffers):pass
@_f
@_p.types(None,arrays.GLuintArray,_cs.GLint,arrays.GLintArray)
def glExtGetRenderbuffersQCOM(renderbuffers,maxRenderbuffers,numRenderbuffers):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLint,_cs.GLenum,arrays.GLintArray)
def glExtGetTexLevelParameterivQCOM(texture,face,level,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glExtGetTexSubImageQCOM(target,level,xoffset,yoffset,zoffset,width,height,depth,format,type,texels):pass
@_f
@_p.types(None,arrays.GLuintArray,_cs.GLint,arrays.GLintArray)
def glExtGetTexturesQCOM(textures,maxTextures,numTextures):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLint)
def glExtTexObjectStateOverrideiQCOM(target,pname,param):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_NV_depth_nonlinear'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_NV_depth_nonlinear',error_checker=_errors._error_checker)
EGL_DEPTH_ENCODING_NONE_NV=_C('EGL_DEPTH_ENCODING_NONE_NV',0)
EGL_DEPTH_ENCODING_NONLINEAR_NV=_C('EGL_DEPTH_ENCODING_NONLINEAR_NV',0x30E3)
EGL_DEPTH_ENCODING_NV=_C('EGL_DEPTH_ENCODING_NV',0x30E2)




'''OpenGL extension SGIX.convolution_accuracy

This module customises the behaviour of the 
OpenGL.raw.GL.SGIX.convolution_accuracy to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds an accuracy hint for convolution.  It
	allows the program to trade off precision for speed.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/convolution_accuracy.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIX.convolution_accuracy import *
from OpenGL.raw.GL.SGIX.convolution_accuracy import _EXTENSION_NAME

def glInitConvolutionAccuracySGIX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


"""Data-type definitions for EGL/GLES"""
import ctypes
from OpenGL._opaque import opaque_pointer_cls as _opaque_pointer_cls
from OpenGL import platform as _p
from OpenGL import extensions 

class _EGLQuerier( extensions.ExtensionQuerier ):
    prefix = 'EGL_'
    assumed_version = [1,0]
    version_prefix = 'EGL_VERSION_EGL_'
    def getDisplay( self ):
        """Retrieve the currently-bound, or the default, display"""
        from OpenGL.EGL import (
            eglGetCurrentDisplay, eglGetDisplay, EGL_DEFAULT_DISPLAY,
        )
        return eglGetCurrentDisplay() or eglGetDisplay(EGL_DEFAULT_DISPLAY)
        
    def pullVersion( self ):
        from OpenGL.EGL import (
            eglQueryString, EGL_VERSION
        )
        return eglQueryString( self.getDisplay(), EGL_VERSION )
    def pullExtensions( self ):
        from OpenGL.EGL import eglQueryString, EGL_EXTENSIONS
        return eglQueryString( self.getDisplay(), EGL_EXTENSIONS )
EGLQuerier=_EGLQuerier()

EGLBoolean = ctypes.c_uint32
EGLenum = ctypes.c_uint32
EGLint = c_int = ctypes.c_int32

EGLConfig = _opaque_pointer_cls( 'EGLConfig' )
EGLContext = _opaque_pointer_cls( 'EGLContext' )
EGLDisplay = _opaque_pointer_cls( 'EGLDisplay' )
EGLSurface = _opaque_pointer_cls( 'EGLSurface' )
EGLClientBuffer = _opaque_pointer_cls( 'EGLClientBuffer' )
EGLImageKHR = EGLImage = _opaque_pointer_cls( 'EGLImageKHR' )

EGLScreenMESA = ctypes.c_ulong
EGLModeMESA = ctypes.c_ulong

EGLNativeFileDescriptorKHR = ctypes.c_int

EGLSyncKHR = EGLSyncNV = EGLSync = _opaque_pointer_cls( 'EGLSync' )
EGLTimeKHR = EGLTimeNV = EGLTime = ctypes.c_ulonglong
EGLuint64KHR = EGLuint64NV = ctypes.c_ulonglong
EGLStreamKHR = _opaque_pointer_cls( 'EGLStream' )
EGLsizeiANDROID = ctypes.c_size_t
EGLAttribKHR = EGLAttrib = ctypes.POINTER( ctypes.c_int32 )

class EGLClientPixmapHI( ctypes.Structure):
    _fields_ = [
        ('pData',ctypes.c_voidp),
        ('iWidth',EGLint),
        ('iHeight',EGLint),
        ('iStride',EGLint),
    ]
class wl_display( ctypes.Structure):
    """Opaque structure from Mesa Wayland API"""
    _fields_ = []

# These are X11... no good, really...
EGLNativeDisplayType = _opaque_pointer_cls( 'EGLNativeDisplayType' )
EGLNativePixmapType = _opaque_pointer_cls( 'EGLNativePixmapType' )
EGLNativeWindowType = _opaque_pointer_cls( 'EGLNativeWindowType' )

NativeDisplayType = EGLNativeDisplayType 
NativePixmapType = EGLNativePixmapType
NativeWindowType = EGLNativeWindowType

# Callback types, this is a hack to avoid making the 
# khr module depend on the platform or needing to change generator for now...
CALLBACK_TYPE = _p.PLATFORM.functionTypeFor( _p.PLATFORM.EGL )
EGLSetBlobFuncANDROID = CALLBACK_TYPE( ctypes.c_voidp, EGLsizeiANDROID, ctypes.c_voidp, EGLsizeiANDROID )
EGLGetBlobFuncANDROID = CALLBACK_TYPE( ctypes.c_voidp, EGLsizeiANDROID, ctypes.c_voidp, EGLsizeiANDROID )

EGL_DEFAULT_DISPLAY = EGLNativeDisplayType()
EGL_NO_CONTEXT = EGLContext()
EGL_NO_DISPLAY = EGLDisplay()
EGL_NO_SURFACE = EGLSurface()
EGL_DONT_CARE = -1

raw_eglQueryString = _p.PLATFORM.EGL.eglQueryString
raw_eglQueryString.restype = ctypes.c_char_p
raw_eglQueryString.__doc__ = """Raw version of eglQueryString that does not check for availability"""

_VERSION_PREFIX = 'EGL_VERSION_EGL_'


[
    'EGLAttrib',
    'EGLAttribKHR',
    'EGLBoolean',
    'EGLClientBuffer',
    'EGLClientPixmapHI',
    'EGLConfig',
    'EGLContext',
    'EGLDisplay',
    'EGLGetBlobFuncANDROID',
    'EGLImageKHR',
    'EGLModeMESA',
    'EGLNativeDisplayType',
    'EGLNativeFileDescriptorKHR',
    'EGLNativePixmapType',
    'EGLNativeWindowType',
    'EGLScreenMESA',
    'EGLSetBlobFuncANDROID',
    'EGLStreamKHR',
    'EGLSurface',
    'EGLSyncKHR',
    'EGLSyncNV',
    'EGLSync',
    'EGLTimeKHR',
    'EGLTimeNV',
    'EGLTime',
    'EGL_DEFAULT_DISPLAY',
    'EGL_DONT_CARE',
    'EGL_NO_CONTEXT',
    'EGL_NO_DISPLAY',
    'EGL_NO_SURFACE',
    'EGLenum',
    'EGLint',
    'EGLsizeiANDROID',
    'EGLuint64KHR',
    'EGLuint64NV',
    'NativeDisplayType',
    'NativePixmapType',
    'NativeWindowType',
    'wl_display',
]



'''OpenGL extension EXT.index_array_formats

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.index_array_formats to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extends the number of packed vertex formats accepted by
	InterleavedArrays to include formats which specify color indexes
	rather than RGBA colors.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/index_array_formats.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.index_array_formats import *
from OpenGL.raw.GL.EXT.index_array_formats import _EXTENSION_NAME

def glInitIndexArrayFormatsEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_VERSION_GL_2_1'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_VERSION_GL_2_1',error_checker=_errors._error_checker)
GL_COMPRESSED_SLUMINANCE=_C('GL_COMPRESSED_SLUMINANCE',0x8C4A)
GL_COMPRESSED_SLUMINANCE_ALPHA=_C('GL_COMPRESSED_SLUMINANCE_ALPHA',0x8C4B)
GL_COMPRESSED_SRGB=_C('GL_COMPRESSED_SRGB',0x8C48)
GL_COMPRESSED_SRGB_ALPHA=_C('GL_COMPRESSED_SRGB_ALPHA',0x8C49)
GL_CURRENT_RASTER_SECONDARY_COLOR=_C('GL_CURRENT_RASTER_SECONDARY_COLOR',0x845F)
GL_FLOAT_MAT2x3=_C('GL_FLOAT_MAT2x3',0x8B65)
GL_FLOAT_MAT2x4=_C('GL_FLOAT_MAT2x4',0x8B66)
GL_FLOAT_MAT3x2=_C('GL_FLOAT_MAT3x2',0x8B67)
GL_FLOAT_MAT3x4=_C('GL_FLOAT_MAT3x4',0x8B68)
GL_FLOAT_MAT4x2=_C('GL_FLOAT_MAT4x2',0x8B69)
GL_FLOAT_MAT4x3=_C('GL_FLOAT_MAT4x3',0x8B6A)
GL_PIXEL_PACK_BUFFER=_C('GL_PIXEL_PACK_BUFFER',0x88EB)
GL_PIXEL_PACK_BUFFER_BINDING=_C('GL_PIXEL_PACK_BUFFER_BINDING',0x88ED)
GL_PIXEL_UNPACK_BUFFER=_C('GL_PIXEL_UNPACK_BUFFER',0x88EC)
GL_PIXEL_UNPACK_BUFFER_BINDING=_C('GL_PIXEL_UNPACK_BUFFER_BINDING',0x88EF)
GL_SLUMINANCE=_C('GL_SLUMINANCE',0x8C46)
GL_SLUMINANCE8=_C('GL_SLUMINANCE8',0x8C47)
GL_SLUMINANCE8_ALPHA8=_C('GL_SLUMINANCE8_ALPHA8',0x8C45)
GL_SLUMINANCE_ALPHA=_C('GL_SLUMINANCE_ALPHA',0x8C44)
GL_SRGB=_C('GL_SRGB',0x8C40)
GL_SRGB8=_C('GL_SRGB8',0x8C41)
GL_SRGB8_ALPHA8=_C('GL_SRGB8_ALPHA8',0x8C43)
GL_SRGB_ALPHA=_C('GL_SRGB_ALPHA',0x8C42)
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glUniformMatrix2x3fv(location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glUniformMatrix2x4fv(location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glUniformMatrix3x2fv(location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glUniformMatrix3x4fv(location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glUniformMatrix4x2fv(location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glUniformMatrix4x3fv(location,count,transpose,value):pass



"""Utility module to parse a Feedback buffer"""
from OpenGL import contextdata
from OpenGL.GL.VERSION import GL_1_1 as _simple

def parseFeedback( buffer, entryCount ):
    """Parse the feedback buffer into Python object records"""
    bufferIndex = 0
    result = []
    getVertex = createGetVertex( )
    while bufferIndex < entryCount:
        token = int(buffer[bufferIndex])
        bufferIndex += 1
        if token in SINGLE_VERTEX_TOKENS:
            vData, bufferIndex = getVertex( buffer, bufferIndex )
            result.append( (SINGLE_VERTEX_TOKENS.get(token), Vertex(*vData)) )
        elif token in DOUBLE_VERTEX_TOKENS:
            vData, bufferIndex = getVertex( buffer, bufferIndex )
            vData2, bufferIndex = getVertex( buffer, bufferIndex )
            result.append( (
                DOUBLE_VERTEX_TOKENS.get(token), 
                Vertex(*vData),
                Vertex(*vData2),
            ) )
        elif token == _simple.GL_PASS_THROUGH_TOKEN:
            result.append( (_simple.GL_PASS_THROUGH_TOKEN, buffer[bufferIndex]))
            bufferIndex += 1
        elif token == _simple.GL_POLYGON_TOKEN:
            temp = [_simple.GL_POLYGON_TOKEN]
            count = int(buffer[bufferIndex])
            bufferIndex += 1
            for item in range(count):
                vData,bufferIndex = getVertex( buffer, bufferIndex )
                temp.append( Vertex(*vData))
            result.append( tuple(temp))
        else:
            raise ValueError( 
                """Unrecognised token %r in feedback stream"""%(token,)
            )
    return result

SINGLE_VERTEX_TOKENS = {
    _simple.GL_BITMAP_TOKEN: _simple.GL_BITMAP_TOKEN,
    _simple.GL_COPY_PIXEL_TOKEN: _simple.GL_COPY_PIXEL_TOKEN,
    _simple.GL_DRAW_PIXEL_TOKEN: _simple.GL_DRAW_PIXEL_TOKEN,
    _simple.GL_POINT_TOKEN: _simple.GL_POINT_TOKEN,
}
DOUBLE_VERTEX_TOKENS = {
    _simple.GL_LINE_TOKEN: _simple.GL_LINE_TOKEN,
    _simple.GL_LINE_RESET_TOKEN: _simple.GL_LINE_RESET_TOKEN,
}
class Vertex( object ):
    """Simplistic holder for vertex data from a feedback buffer"""
    __slots__ = ('vertex','color','texture')
    def __init__( self, vertex,color=None,texture=None):
        """Store values for access"""
        self.vertex = vertex 
        self.color = color 
        self.texture = texture 
def createGetVertex( ):
    mode = contextdata.getValue( "GL_FEEDBACK_BUFFER_TYPE" )
    indexMode = _simple.glGetBooleanv( _simple.GL_INDEX_MODE )
    colorSize = [ 4,1 ][ int(indexMode) ]
    if mode in (_simple.GL_2D,_simple.GL_3D):
        if mode == _simple.GL_2D:
            size = 2
        else:
            size = 3
        def getVertex( buffer, bufferIndex ):
            end = bufferIndex+size
            return (buffer[bufferIndex:end],None,None),end 
    elif mode == _simple.GL_3D_COLOR:
        def getVertex( buffer, bufferIndex ):
            end = bufferIndex+3
            colorEnd = end + colorSize
            return (buffer[bufferIndex:end],buffer[end:colorEnd],None),colorEnd 
    else:
        if mode == _simple.GL_3D_COLOR_TEXTURE:
            size = 3
        else:
            size = 4
        def getVertex( buffer, bufferIndex ):
            end = bufferIndex+size
            colorEnd = end + colorSize
            textureEnd = colorEnd + 4
            return (buffer[bufferIndex:end],buffer[end:colorEnd],buffer[colorEnd:textureEnd]),textureEnd
    return getVertex



'''OpenGL extension ARB.seamless_cubemap_per_texture

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.seamless_cubemap_per_texture to provide a more 
Python-friendly API

Overview (from the spec)
	
	In unextended OpenGL, cube maps are treated as sets of six, independent
	texture images. Once a face is selected from the set, it is treated exactly
	as any other two-dimensional texture would be. When sampling linearly from
	the texture, all of the individual texels that would be used to to create
	the final, bilinear sample values are taken from the same cube face. The
	normal, two-dimensional texture coordinate wrapping modes are honored.
	This sometimes causes seams to appear in cube maps.
	
	ARB_seamless_cube_map (and subsequently, OpenGL 3.2) addresses this issue
	by providing a mechanism whereby an implementation could take each of the
	taps of a bilinear sample from a different face, spanning face boundaries
	and providing seamless filtering from cube map textures. However, in
	ARB_seamless_cube_map, this feature was exposed as a global state,
	affecting all bound cube map textures. It was not possible to mix seamless
	and per-face cube map sampling modes during sampling. Furthermore, if an
	application included cube maps that were meant to be sampled seamlessly
	and non-seamlessly, it would have to track this state and enable or disable
	seamless cube map sampling as needed.
	
	This extension addresses this issue and provides an orthogonal method for
	allowing an implementation to provide a per-texture setting for enabling
	seamless sampling from cube maps.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/seamless_cubemap_per_texture.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.seamless_cubemap_per_texture import *
from OpenGL.raw.GL.ARB.seamless_cubemap_per_texture import _EXTENSION_NAME

def glInitSeamlessCubemapPerTextureARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension ARB.seamless_cube_map

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.seamless_cube_map to provide a more 
Python-friendly API

Overview (from the spec)
	
	When sampling from cube map textures, a three-dimensional texture
	coordinate is used to select one of the cube map faces and generate
	a two dimensional texture coordinate ( s t ), at which a texel is
	sampled from the determined face of the cube map texture. Each face
	of the texture is treated as an independent two-dimensional texture,
	and the generated ( s t ) coordinate is subjected to the same
	clamping and wrapping rules as for any other two dimensional texture
	fetch.
	
	Although it is unlikely that the generated ( s t ) coordinate lies
	significantly outside the determined cube map face, it is often the
	case that the locations of the individual elements required during a
	linear sampling do not lie within the determined face, and their
	coordinates will therefore be modified by the selected clamping and
	wrapping rules. This often has the effect of producing seams or
	other discontinuities in the sampled texture.
	
	This extension allows implementations to take samples from adjacent
	cube map faces, providing the ability to create seamless cube maps.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/seamless_cube_map.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.seamless_cube_map import *
from OpenGL.raw.GL.ARB.seamless_cube_map import _EXTENSION_NAME

def glInitSeamlessCubeMapARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension ARB.vertex_type_10f_11f_11f_rev

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.vertex_type_10f_11f_11f_rev to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds the following data format:
	
	A new vertex attribute data format: a packed 11.11.10 unsigned
	float vertex data format.  This vertex data format can be used
	to describe a compressed 3 component stream of values that can
	be represented by 10- or 11-bit unsigned floating point values.
	
	The UNSIGNED_INT_10F_11F_11F_REV vertex attribute type is
	equivalent to the R11F_G11F_B10F texture internal format.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/vertex_type_10f_11f_11f_rev.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.vertex_type_10f_11f_11f_rev import *
from OpenGL.raw.GL.ARB.vertex_type_10f_11f_11f_rev import _EXTENSION_NAME

def glInitVertexType10F11F11FRevARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_KHR_stream'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_KHR_stream',error_checker=_errors._error_checker)
EGL_BAD_STATE_KHR=_C('EGL_BAD_STATE_KHR',0x321C)
EGL_BAD_STREAM_KHR=_C('EGL_BAD_STREAM_KHR',0x321B)
EGL_CONSUMER_FRAME_KHR=_C('EGL_CONSUMER_FRAME_KHR',0x3213)
EGL_CONSUMER_LATENCY_USEC_KHR=_C('EGL_CONSUMER_LATENCY_USEC_KHR',0x3210)
# EGL_NO_STREAM_KHR=_C('EGL_NO_STREAM_KHR',((EGLStreamKHR)0))
EGL_PRODUCER_FRAME_KHR=_C('EGL_PRODUCER_FRAME_KHR',0x3212)
EGL_STREAM_STATE_CONNECTING_KHR=_C('EGL_STREAM_STATE_CONNECTING_KHR',0x3216)
EGL_STREAM_STATE_CREATED_KHR=_C('EGL_STREAM_STATE_CREATED_KHR',0x3215)
EGL_STREAM_STATE_DISCONNECTED_KHR=_C('EGL_STREAM_STATE_DISCONNECTED_KHR',0x321A)
EGL_STREAM_STATE_EMPTY_KHR=_C('EGL_STREAM_STATE_EMPTY_KHR',0x3217)
EGL_STREAM_STATE_KHR=_C('EGL_STREAM_STATE_KHR',0x3214)
EGL_STREAM_STATE_NEW_FRAME_AVAILABLE_KHR=_C('EGL_STREAM_STATE_NEW_FRAME_AVAILABLE_KHR',0x3218)
EGL_STREAM_STATE_OLD_FRAME_AVAILABLE_KHR=_C('EGL_STREAM_STATE_OLD_FRAME_AVAILABLE_KHR',0x3219)
@_f
@_p.types(_cs.EGLStreamKHR,_cs.EGLDisplay,arrays.GLintArray)
def eglCreateStreamKHR(dpy,attrib_list):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLStreamKHR)
def eglDestroyStreamKHR(dpy,stream):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLStreamKHR,_cs.EGLenum,arrays.GLintArray)
def eglQueryStreamKHR(dpy,stream,attribute,value):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLStreamKHR,_cs.EGLenum,arrays.GLuint64Array)
def eglQueryStreamu64KHR(dpy,stream,attribute,value):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLStreamKHR,_cs.EGLenum,_cs.EGLint)
def eglStreamAttribKHR(dpy,stream,attribute,value):pass



'''OpenGL extension SGIS.texture_edge_clamp

This module customises the behaviour of the 
OpenGL.raw.GL.SGIS.texture_edge_clamp to provide a more 
Python-friendly API

Overview (from the spec)
	
	The base OpenGL provides clamping such that the texture coordinates are
	limited to exactly the range [0,1].  When a texture coordinate is
	clamped using this algorithm, the texture sampling filter straddles the
	edge of the texture image, taking 1/2 its sample values from within the
	texture image, and the other 1/2 from the texture border.  It is
	sometimes desirable to clamp a texture without requiring a border, and
	without using the constant border color.
	
	This extension defines a new texture clamping algorithm.
	CLAMP_TO_EDGE_SGIS clamps texture coordinates at all mipmap levels such
	that the texture filter never samples a border texel.  When used with a
	NEAREST or a LINEAR filter, the color returned when clamping is derived
	only from texels at the edge of the texture image.  When used with
	FILTER4 filters, the filter operations of CLAMP_TO_EDGE_SGIS are defined
	but don't result in a nice clamp-to-edge color.
	
	CLAMP_TO_EDGE_SGIS is supported by 1, 2, and 3-dimensional textures
	only.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIS/texture_edge_clamp.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIS.texture_edge_clamp import *
from OpenGL.raw.GL.SGIS.texture_edge_clamp import _EXTENSION_NAME

def glInitTextureEdgeClampSGIS():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.WGL import _types as _cs
# End users want this...
from OpenGL.raw.WGL._types import *
from OpenGL.raw.WGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'WGL_I3D_digital_video_control'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.WGL,'WGL_I3D_digital_video_control',error_checker=_errors._error_checker)
WGL_DIGITAL_VIDEO_CURSOR_ALPHA_FRAMEBUFFER_I3D=_C('WGL_DIGITAL_VIDEO_CURSOR_ALPHA_FRAMEBUFFER_I3D',0x2050)
WGL_DIGITAL_VIDEO_CURSOR_ALPHA_VALUE_I3D=_C('WGL_DIGITAL_VIDEO_CURSOR_ALPHA_VALUE_I3D',0x2051)
WGL_DIGITAL_VIDEO_CURSOR_INCLUDED_I3D=_C('WGL_DIGITAL_VIDEO_CURSOR_INCLUDED_I3D',0x2052)
WGL_DIGITAL_VIDEO_GAMMA_CORRECTED_I3D=_C('WGL_DIGITAL_VIDEO_GAMMA_CORRECTED_I3D',0x2053)
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.c_int,ctypes.POINTER(_cs.c_int))
def wglGetDigitalVideoParametersI3D(hDC,iAttribute,piValue):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.c_int,ctypes.POINTER(_cs.c_int))
def wglSetDigitalVideoParametersI3D(hDC,iAttribute,piValue):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_HP_image_transform'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_HP_image_transform',error_checker=_errors._error_checker)
GL_AVERAGE_HP=_C('GL_AVERAGE_HP',0x8160)
GL_CUBIC_HP=_C('GL_CUBIC_HP',0x815F)
GL_IMAGE_CUBIC_WEIGHT_HP=_C('GL_IMAGE_CUBIC_WEIGHT_HP',0x815E)
GL_IMAGE_MAG_FILTER_HP=_C('GL_IMAGE_MAG_FILTER_HP',0x815C)
GL_IMAGE_MIN_FILTER_HP=_C('GL_IMAGE_MIN_FILTER_HP',0x815D)
GL_IMAGE_ROTATE_ANGLE_HP=_C('GL_IMAGE_ROTATE_ANGLE_HP',0x8159)
GL_IMAGE_ROTATE_ORIGIN_X_HP=_C('GL_IMAGE_ROTATE_ORIGIN_X_HP',0x815A)
GL_IMAGE_ROTATE_ORIGIN_Y_HP=_C('GL_IMAGE_ROTATE_ORIGIN_Y_HP',0x815B)
GL_IMAGE_SCALE_X_HP=_C('GL_IMAGE_SCALE_X_HP',0x8155)
GL_IMAGE_SCALE_Y_HP=_C('GL_IMAGE_SCALE_Y_HP',0x8156)
GL_IMAGE_TRANSFORM_2D_HP=_C('GL_IMAGE_TRANSFORM_2D_HP',0x8161)
GL_IMAGE_TRANSLATE_X_HP=_C('GL_IMAGE_TRANSLATE_X_HP',0x8157)
GL_IMAGE_TRANSLATE_Y_HP=_C('GL_IMAGE_TRANSLATE_Y_HP',0x8158)
GL_POST_IMAGE_TRANSFORM_COLOR_TABLE_HP=_C('GL_POST_IMAGE_TRANSFORM_COLOR_TABLE_HP',0x8162)
GL_PROXY_POST_IMAGE_TRANSFORM_COLOR_TABLE_HP=_C('GL_PROXY_POST_IMAGE_TRANSFORM_COLOR_TABLE_HP',0x8163)
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetImageTransformParameterfvHP(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetImageTransformParameterivHP(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfloat)
def glImageTransformParameterfHP(target,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glImageTransformParameterfvHP(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLint)
def glImageTransformParameteriHP(target,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glImageTransformParameterivHP(target,pname,params):pass



'''OpenGL extension OML.interlace

This module customises the behaviour of the 
OpenGL.raw.GL.OML.interlace to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a way to interlace rows of pixels when
	drawing, reading, or copying pixel rectangles or texture images. In
	this context, interlacing means skiping over rows of pixels or
	texels in the destination. This is useful for dealing with video
	data since a single frame of video is typically composed from two
	images or fields: one image specifying the data for even rows of the
	frame and the other image specifying the data for odd rows of the
	frame.
	
	The functionality provided by this extension is a combination
	of the older SGIX_interlace and INGR_interlace_read extensions,
	with  changes applying interlacing to texture image queries.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OML/interlace.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.OML.interlace import *
from OpenGL.raw.GL.OML.interlace import _EXTENSION_NAME

def glInitInterlaceOML():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_SGIX_pixel_tiles'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_SGIX_pixel_tiles',error_checker=_errors._error_checker)
GL_PIXEL_TILE_BEST_ALIGNMENT_SGIX=_C('GL_PIXEL_TILE_BEST_ALIGNMENT_SGIX',0x813E)
GL_PIXEL_TILE_CACHE_INCREMENT_SGIX=_C('GL_PIXEL_TILE_CACHE_INCREMENT_SGIX',0x813F)
GL_PIXEL_TILE_CACHE_SIZE_SGIX=_C('GL_PIXEL_TILE_CACHE_SIZE_SGIX',0x8145)
GL_PIXEL_TILE_GRID_DEPTH_SGIX=_C('GL_PIXEL_TILE_GRID_DEPTH_SGIX',0x8144)
GL_PIXEL_TILE_GRID_HEIGHT_SGIX=_C('GL_PIXEL_TILE_GRID_HEIGHT_SGIX',0x8143)
GL_PIXEL_TILE_GRID_WIDTH_SGIX=_C('GL_PIXEL_TILE_GRID_WIDTH_SGIX',0x8142)
GL_PIXEL_TILE_HEIGHT_SGIX=_C('GL_PIXEL_TILE_HEIGHT_SGIX',0x8141)
GL_PIXEL_TILE_WIDTH_SGIX=_C('GL_PIXEL_TILE_WIDTH_SGIX',0x8140)




'''OpenGL extension ARB.gpu_shader5

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.gpu_shader5 to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a set of new features to the OpenGL Shading
	Language and related APIs to support capabilities of new GPUs, extending
	the capabilities of version 1.50 of the OpenGL Shading Language.  Shaders
	using the new functionality provided by this extension should enable this
	functionality via the construct
	
	  #extension GL_ARB_gpu_shader5 : require     (or enable)
	
	This extension provides a variety of new features for all shader types,
	including:
	
	  * support for indexing into arrays of samplers using non-constant
	    indices, as long as the index doesn't diverge if multiple shader
	    invocations are run in lockstep;
	
	  * extending the uniform block capability of OpenGL 3.1 and 3.2 to allow
	    shaders to index into an array of uniform blocks;
	
	  * support for implicitly converting signed integer types to unsigned
	    types, as well as more general implicit conversion and function
	    overloading infrastructure to support new data types introduced by
	    other extensions;
	
	  * a "precise" qualifier allowing computations to be carried out exactly
	    as specified in the shader source to avoid optimization-induced
	    invariance issues (which might cause cracking in tessellation);
	
	  * new built-in functions supporting:
	
	    * fused floating-point multiply-add operations;
	
	    * splitting a floating-point number into a significand and exponent
	      (frexp), or building a floating-point number from a significand and
	      exponent (ldexp);
	
	    * integer bitfield manipulation, including functions to find the
	      position of the most or least significant set bit, count the number
	      of one bits, and bitfield insertion, extraction, and reversal;
	
	    * packing and unpacking vectors of small fixed-point data types into a
	      larger scalar; and
	
	    * convert floating-point values to or from their integer bit
	      encodings;
	
	  * extending the textureGather() built-in functions provided by
	    ARB_texture_gather:
	
	    * allowing shaders to select any single component of a multi-component
	      texture to produce the gathered 2x2 footprint;
	
	    * allowing shaders to perform a per-sample depth comparison when
	      gathering the 2x2 footprint using for shadow sampler types;
	
	    * allowing shaders to use arbitrary offsets computed at run-time to
	      select a 2x2 footprint to gather from; and
	
	    * allowing shaders to use separate independent offsets for each of the
	      four texels returned, instead of requiring a fixed 2x2 footprint.
	
	This extension also provides some new capabilities for individual
	shader types, including:
	
	  * support for instanced geometry shaders, where a geometry shader may be
	    run multiple times for each primitive, including a built-in
	    gl_InvocationID to identify the invocation number;
	
	  * support for emitting vertices in a geometry program where each vertex
	    emitted may be directed independently at a specified vertex stream (as
	    provided by ARB_transform_feedback3), and where each shader output is
	    associated with a stream;
	
	  * support for reading a mask of covered samples in a fragment shader;
	    and
	
	  * support for interpolating a fragment shader input at a programmable
	    offset relative to the pixel center, a programmable sample number, or
	    at the centroid.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/gpu_shader5.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.gpu_shader5 import *
from OpenGL.raw.GL.ARB.gpu_shader5 import _EXTENSION_NAME

def glInitGpuShader5ARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension SUN.triangle_list

This module customises the behaviour of the 
OpenGL.raw.GL.SUN.triangle_list to provide a more 
Python-friendly API

Overview (from the spec)
	
	OpenGL has two chained triangle primitives, TRIANGLE_STRIP and
	TRIANGLE_FAN.  For multiple, consecutive triangle strips or
	triangle fans, the overhead of Begin and End, or separate calls to
	DrawArrays, can be significant depending on the number of triangles
	per strip or fan.
	
	Many surface tessellators produce triangle strips with very few
	triangles per strip before needing to restart a new strip.  Even
	sophisticated tessellators typically need to restart a new strip,
	or switch from a triangle strip to a triangle fan, many times
	within a single object.  Such tessellators can often produce a more
	efficient tessellation--one with fewer vertices--by mixing strips
	and fans within the same object.  The ability to switch from one to
	the other without restarting the strip or fan yields even more
	savings.  Unfortunately, the overhead of switching from a triangle
	strip to a triangle fan, or vice versa, can reduce, or even
	eliminate the benefit gained from reducing the number of vertices.
	
	A new triangle list primitive, along with an associated replacement
	code attribute, is defined by this extension to allow multiple
	triangle strips and fans to be specified within the same Begin/End
	pair or from a single call to DrawArrays.  The triangle list
	extension also provides the means to switch between triangle strips
	and triangle fans with or without restarting the strip or fan.
	
	TRIANGLE_LIST is a new primitive type (i.e., new Begin mode) that
	uses the ReplacementCodeSUN state attribute to determine whether the
	current vertex replaces the oldest vertex, as in a triangle strip,
	the middle vertex, as in a triangle fan, or restarts a new chained
	triangle list.  The first vertex of a new triangle list is
	implicitly treated as a RESTART.  The first three vertices complete
	the first triangle, after which the replacement codes of the vertex
	are used.  The two vertices immediately following a
	restart--including the implicit restart on the first vertex--are
	ignored.  The ReplacementCodeSUN attribute is part of the vertex
	state, and is only used by the TRIANGLE_LIST primitive.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SUN/triangle_list.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SUN.triangle_list import *
from OpenGL.raw.GL.SUN.triangle_list import _EXTENSION_NAME

def glInitTriangleListSUN():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glReplacementCodeuivSUN.code size not checked against ''
glReplacementCodeuivSUN=wrapper.wrapper(glReplacementCodeuivSUN).setInputArraySize(
    'code', None
)
# INPUT glReplacementCodeusvSUN.code size not checked against ''
glReplacementCodeusvSUN=wrapper.wrapper(glReplacementCodeusvSUN).setInputArraySize(
    'code', None
)
# INPUT glReplacementCodeubvSUN.code size not checked against ''
glReplacementCodeubvSUN=wrapper.wrapper(glReplacementCodeubvSUN).setInputArraySize(
    'code', None
)
# INPUT glReplacementCodePointerSUN.pointer size not checked against 'type,stride'
glReplacementCodePointerSUN=wrapper.wrapper(glReplacementCodePointerSUN).setInputArraySize(
    'pointer', None
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_MESAX_texture_stack'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_MESAX_texture_stack',error_checker=_errors._error_checker)
GL_PROXY_TEXTURE_1D_STACK_MESAX=_C('GL_PROXY_TEXTURE_1D_STACK_MESAX',0x875B)
GL_PROXY_TEXTURE_2D_STACK_MESAX=_C('GL_PROXY_TEXTURE_2D_STACK_MESAX',0x875C)
GL_TEXTURE_1D_STACK_BINDING_MESAX=_C('GL_TEXTURE_1D_STACK_BINDING_MESAX',0x875D)
GL_TEXTURE_1D_STACK_MESAX=_C('GL_TEXTURE_1D_STACK_MESAX',0x8759)
GL_TEXTURE_2D_STACK_BINDING_MESAX=_C('GL_TEXTURE_2D_STACK_BINDING_MESAX',0x875E)
GL_TEXTURE_2D_STACK_MESAX=_C('GL_TEXTURE_2D_STACK_MESAX',0x875A)




'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_SGIS_texture4D'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_SGIS_texture4D',error_checker=_errors._error_checker)
GL_MAX_4D_TEXTURE_SIZE_SGIS=_C('GL_MAX_4D_TEXTURE_SIZE_SGIS',0x8138)
GL_PACK_IMAGE_DEPTH_SGIS=_C('GL_PACK_IMAGE_DEPTH_SGIS',0x8131)
GL_PACK_SKIP_VOLUMES_SGIS=_C('GL_PACK_SKIP_VOLUMES_SGIS',0x8130)
GL_PROXY_TEXTURE_4D_SGIS=_C('GL_PROXY_TEXTURE_4D_SGIS',0x8135)
GL_TEXTURE_4DSIZE_SGIS=_C('GL_TEXTURE_4DSIZE_SGIS',0x8136)
GL_TEXTURE_4D_BINDING_SGIS=_C('GL_TEXTURE_4D_BINDING_SGIS',0x814F)
GL_TEXTURE_4D_SGIS=_C('GL_TEXTURE_4D_SGIS',0x8134)
GL_TEXTURE_WRAP_Q_SGIS=_C('GL_TEXTURE_WRAP_Q_SGIS',0x8137)
GL_UNPACK_IMAGE_DEPTH_SGIS=_C('GL_UNPACK_IMAGE_DEPTH_SGIS',0x8133)
GL_UNPACK_SKIP_VOLUMES_SGIS=_C('GL_UNPACK_SKIP_VOLUMES_SGIS',0x8132)
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLenum,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei,_cs.GLint,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glTexImage4DSGIS(target,level,internalformat,width,height,depth,size4d,border,format,type,pixels):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glTexSubImage4DSGIS(target,level,xoffset,yoffset,zoffset,woffset,width,height,depth,size4d,format,type,pixels):pass
